<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://www.pixeljar.com
 * @since      1.0.0
 *
 * @package    Adsanity_Urav
 * @subpackage Adsanity_Urav/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Adsanity_Urav
 * @subpackage Adsanity_Urav/admin
 * @author     Pixel Jar <info@pixeljar.com>
 */
class Adsanity_Urav_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * The options of this plugin.
	 *
	 * @since    1.0.0
	 */
	private $options;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;
		$this->get_options();

	}

	/**
	 * Retrieve the options of this plugin.
	 *
	 * @since    1.0.0
	 */
	private function get_options() {

		$this->options = get_option( 'adsanity-user-role-ad-visibility-options' );

	}

	/**
	 * Add options to AdSanity Add-Ons Settings tab
	 *
	 * @since    1.0.0
	 */
	public function add_settings_tab( $addons ) {

		$addons[] = array(
			'slug' => 'user-role-ad-visibility',
			'name' => esc_html__( 'User Role Ad Visibility', 'adsanity-urav' ),
		);
		return $addons;

	}

	/**
	 * Add the settings page
	 *
	 * @since    1.0.0
	 */
	public function settings() {

		/**
		 * Register settings
		 */
		register_setting(
			'adsanity-user-role-ad-visibility-options',
			'adsanity-user-role-ad-visibility-options',
			array( $this, 'validate_options' )
		);

		/**
		 * Register the settings section
		 */
		add_settings_section(
			$this->plugin_name . '-options',
			esc_html__(
				sprintf( '%s User Role Ad Visibility', 'AdSanity' ),
				'adsanity-urav'
			),
			array( $this, 'section_view_cb' ),
			'adsanity-user-role-ad-visibility-options'
		);

		/**
		 * Register the users field
		 */
		add_settings_field(
			'user-roles',
			esc_html__( 'Hide Ads From These User Roles:' ),
			array( $this, 'user_roles_cb' ),
			'adsanity-user-role-ad-visibility-options',
			$this->plugin_name . '-options',
			array(
				'label_for' => 'user-roles'
			)
		);

	}

	/**
	 * Validate the options
	 *
	 * @since    1.0.0
	 */
	public function validate_options( $dirty ) {

		$clean = array();

		if ( is_array( $dirty ) ) {
			foreach ( $dirty as $role ) {
				array_push( $clean, sanitize_text_field( $role ) );
			}
		}

		return $clean;

	}

	/**
	 *
	 *
	 * @since    1.0.0
	 */
	public function section_view_cb() { }

	/**
	 *
	 *
	 * @since    1.0.0
	 */
	public function user_roles_cb() {

		require_once plugin_dir_path( __FILE__ ) . 'partials/user-roles.php';

	}

}
