<?php

/**
 * Admin plugin functionality
 */
class Adsanity_ABD_Admin {

	/**
	 * Unique identifier
	 */
	private $plugin_name;

	/**
	 * The plugin options
	 */
	private $options;

	/**
	 * The version for this plugin
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;
		$this->set_options();
	}

	/**
	 * Settings page scripts
	 */
	public function enqueue_script( $hook ) {

		if( $hook !== 'ads_page_adsanity-settings' ) {
			return;
		}

		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/adsanity-abd-admin.js', array( 'jquery' ), $this->version );

	}

	/**
	 * Settings page styles
	 */
	public function enqueue_style( $hook ) {

		if( $hook !== 'ads_page_adsanity-settings' ) {
			return;
		}

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/adsanity-abd-admin.css', array(), $this->version );

	}

	/**
	 * Add options to AdSanity Add-Ons Settings tab
	 */
	public function add_settings_tab( $addons = array() ) {

		$addons[] = array(
			'slug' => 'ad-block-detection',
			'name' => __( 'Ad Block Detection', 'adsanity-abd' ),
		);

		return $addons;

	}

	/**
	 * Sets the class variable $options
	 */
	private function set_options() {

		$this->options = get_option( 'adsanity-ad-block-detection-options' );

	}

	/**
	 * Add error message
	 */
	private function add_error( $key, $message ) {

		add_settings_error(
			'adsanity-ad-block-detection-options',
			$key,
			$message,
			'error'
		);

	}

	/**
	 * Register plugin settings
	 */
	public function register_settings() {

		register_setting(
			'adsanity-ad-block-detection-options',
			'adsanity-ad-block-detection-options',
			array( $this, 'validate_options' )
		);

	}

	/**
	 * Register settings sections
	 */
	public function register_sections() {

		add_settings_section(
			$this->plugin_name . '-options',
			sprintf( __( '%s Ad Block Detection', 'adsanity-abd' ), 'AdSanity' ),
			array( $this, 'section_view' ),
			'adsanity-ad-block-detection-options'
		);

	}

	/**
	 * Register settings fields
	 */
	public function register_fields() {

		add_settings_field(
			'show-warning-on',
			esc_html__( 'Show Warning On:', 'adsanity-abd' ),
			array( $this, 'show_warning_on_cb' ),
			'adsanity-ad-block-detection-options',
			$this->plugin_name . '-options',
			[
				'label_for' => 'show-warning-on'
			]
		);

		add_settings_field(
			'on-ad-block-detection',
			esc_html__( 'On Ad Block Detection:', 'adsanity-abd' ),
			array( $this, 'on_ad_block_detection_cb' ),
			'adsanity-ad-block-detection-options',
			$this->plugin_name . '-options',
			[
				'label_for' => 'on-ad-block-detection'
			]
		);

		add_settings_field(
			'warning-message',
			esc_html__( 'Warning Modal Message:', 'adsanity-abd' ),
			array( $this, 'warning_message_cb' ),
			'adsanity-ad-block-detection-options',
			$this->plugin_name . '-options',
			[
				'label_for' => 'warning-message'
			]
		);

		add_settings_field(
			'warning-refresh',
			esc_html__( 'Refresh Button Text:', 'adsanity-abd' ),
			array( $this, 'warning_refresh_cb' ),
			'adsanity-ad-block-detection-options',
			$this->plugin_name . '-options',
			[
				'label_for' => 'warning-refresh'
			]
		);

		add_settings_field(
			'redirect',
			esc_html__( 'Redirect to Page:', 'adsanity-abd' ),
			array( $this, 'redirect_cb' ),
			'adsanity-ad-block-detection-options',
			$this->plugin_name . '-options',
			[
				'label_for' => 'redirect'
			]
		);

		add_settings_field(
			'link-back-text',
			esc_html__( 'Redirect link text:', 'adsanity-abd' ),
			array( $this, 'link_back_cb' ),
			'adsanity-ad-block-detection-options',
			$this->plugin_name . '-options',
			[
				'label_for' => 'link-back-text'
			]
		);

		add_settings_field(
			'mandatory-warning',
			esc_html__( 'Warning Mode:', 'adsanity-abd' ),
			array( $this, 'mandatory_warning_cb' ),
			'adsanity-ad-block-detection-options',
			$this->plugin_name . '-options',
			[
				'label_for' => 'mandatory-warning'
			]
		);

		add_settings_field(
			'warning-days',
			esc_html__( 'Days to dismiss:', 'adsanity-abd' ),
			array( $this, 'warning_days_cb' ),
			'adsanity-ad-block-detection-options',
			$this->plugin_name . '-options',
			[
				'label_for' => 'warning-days'
			]
		);

	}

	/**
	 * Validate options
	 */
	public function validate_options( $dirty ) {

		$options = $this->options;

		// If an option is not set, unset it from $dirty
		if ( ! isset( $dirty['post_type'] ) ) {
			unset( $dirty['post_type'] );
			$this->add_error(
				'no-post-type',
				__( 'You must enter at least one post type.', 'adsanity-abd' )
			);
		}

		// Text input will equal 0 if empty, don't use isset()
		if ( ! $dirty['warning_message'] ) {
			unset( $dirty['warning_message'] );
			$this->add_error(
				'no-warning-message',
				__( 'You must enter a warning message.', 'adsanity-abd' )
			);
		}

		// Text input will equal 0 if empty, don't use isset()
		if ( ! $dirty['warning_refresh'] ) {
			unset( $dirty['warning_refresh'] );
			$this->add_error(
				'no-warning-refresh',
				__( 'You must enter refresh button text', 'adsanity-abd' )
			);
		}

		// Text input will equal 0 if empty, don't use isset()
		if ( ! $dirty['link_back'] ) {
			unset( $dirty['link_back'] );
			$this->add_error(
				'no-link-back',
				__( 'You must enter text for link back', 'adsanity-abd' )
			);
		}

		$clean = array_merge( $options, $dirty );
		return $clean;

	}

	/**
	 * Creates a settings section
	 */
	public function section_view( $params ) {

		include( plugin_dir_path( __FILE__ ) . 'partials/adsanity-abd-admin-section-view.php' );

	}

	/**
	 * Callback for show warning on field
	 */
	public function show_warning_on_cb( $args ) {

		$post_types_args = array(
			'show_ui' => true
		);
		$post_types = get_post_types( $post_types_args );

		$i = 0;

		?>

		<td>
			<select name="adsanity-ad-block-detection-options[post_type][]" multiple style="width:100%;">

			<?php

			foreach( $post_types as $post_type ) {

				if ( 'ads' === $post_type ||
				     'attachment' === $post_type ||
				     'wp_block' === $post_type ) {
					continue;
				}

				if ( ! is_array( $this->options['post_type'] ) ) {
					$selected = '';
				} else {
					$selected = selected( in_array( $post_type, $this->options['post_type'] ) );
				}

				printf(
					'<option value="%s" %s>%s</option>',
					esc_attr( $post_type ),
					$selected,
					esc_html( $post_type )
				);

				++$i;

			}
			?>

			</select>
		</td>

		<?php
	}

	/**
	 * Callback for on ad block detection field
	 */
	public function on_ad_block_detection_cb( $args ) { ?>

		<td><fieldset>

		<?php

			$input_format = '
				<label for="%2$s">
					<input type="radio" value="%4$s" id="%2$s" name="%3$s" %5$s class="%2$s"/>
					%1$s
				</label><br>
			';

			printf( $input_format,
				esc_html__( 'Warning Modal', 'adsanity-abd' ),
				esc_attr( $args['label_for'] ),
				esc_attr( 'adsanity-ad-block-detection-options[behavior]' ),
				esc_attr( 'modal' ),
				checked( in_array( 'modal', $this->options ), true, false )
			);

			printf( $input_format,
				esc_html__( 'Redirect', 'adsanity-abd' ),
				esc_attr( $args['label_for'] ),
				esc_attr( 'adsanity-ad-block-detection-options[behavior]' ),
				esc_attr( 'redirect' ),
				checked( in_array( 'redirect', $this->options ), true, false )
			);

		?>

		</fieldset></td>

	<?php }

	/**
	 * Callback for warning message field
	 */
	public function warning_message_cb( $args ) { ?>

		<td><fieldset>

		<?php

			$settings = array(
				'textarea_name' => esc_attr( 'adsanity-ad-block-detection-options[warning_message]' )
			);

			wp_editor( $this->options['warning_message'], $args['label_for'], $settings );

		?>

		</fieldset></td>

	<?php }

	/**
	 * Callback for warning refresh field
	 */
	public function warning_refresh_cb( $args ) { ?>

		<td><fieldset>

		<?php

			$input_format = '
				<input type="text" value="%1$s" name="%2$s" id="%3$s" />
				<br>
			';

			printf(	$input_format,
				esc_attr( $this->options['warning_refresh'] ),
				esc_attr( 'adsanity-ad-block-detection-options[warning_refresh]' ),
				esc_attr( $args['label_for'] )

			);

		?>

		</fieldset></td>

	<?php }

	/**
	 * Callback for redirect field
	 */
	public function redirect_cb( $args ) { ?>

		<td><fieldset>
		<select name="adsanity-ad-block-detection-options[redirect_page]">

		<?php

		$pages = get_pages();

		$option_format = '
			<option value="%1$s" %3$s>%2$s</option>
		';

		foreach( $pages as $page ) {

			printf( $option_format,
				esc_attr( $page->guid ),
				esc_html( $page->post_title ),
				selected( ( $page->guid === $this->options['redirect_page'] ), true, false )
			);
		}

		?>

		</select>
		</fieldset></td>

	<?php }

	/**
	 * Callback for link back text
	 */
	public function link_back_cb( $args ) { ?>

		<td><fieldset>

		<?php

			$input_format = '
				<input type="text" value="%1$s" name="%2$s" id="%3$s" />
				<br>
			';

			printf(	$input_format,
				esc_attr( $this->options['link_back'] ),
				esc_attr( 'adsanity-ad-block-detection-options[link_back]' ),
				esc_attr( $args['label_for'] )

			);

		?>

		</fieldset></td>

	<?php }

	/**
	 * Toggle between Mandatory and Warning Mode
	 */
	public function mandatory_warning_cb( $args ) { ?>

		<td><fieldset>

		<?php

			if ( isset( $this->options['mandatory_warning'] ) ) {
				$value = $this->options['mandatory_warning'];
			} else {
				$value = '';
			}

			$input_format = '<label for="%3$s">
				<input type="radio" value="%1$s" name="%2$s" %4$s class="%3$s" />%5$s</label>';

			printf(	$input_format,
				esc_attr( 'mandatory' ),
				esc_attr( 'adsanity-ad-block-detection-options[mandatory_warning]' ),
				esc_attr( $args['label_for'] ),
				checked( $value !== 'warning', true, false ), // This creates a default
				esc_html__( 'Mandatory - Force users to disable ad block', 'adsanity-abd' )
			);

			echo '<br>';

			printf(	$input_format,
				esc_attr( 'warning' ),
				esc_attr( 'adsanity-ad-block-detection-options[mandatory_warning]' ),
				esc_attr( $args['label_for'] ),
				checked( $value === 'warning', true, false ),
				esc_html__( 'Warning - Allow users to dismiss warning for a number of days', 'adsanity-abd' )
			);

		?>

	</fieldset></td>

	<?php }

	/**
	 * The number of days before the warning is shown again
	 */
	public function warning_days_cb( $args ) { ?>

		<td><fieldset>

		<?php

			if ( isset( $this->options['warning_days'] ) ) {
				$days = $this->options['warning_days'];
			} else {
				$days = 30;
			}

			printf( '<input name="%s" value="%d" type="number" />',
				esc_attr( 'adsanity-ad-block-detection-options[warning_days]' ),
				intval( $days )
			);

		?>

	</fieldset></td>

	<?php }

	/**
	 * Adds the changelog to AdSanity's main changelog page.
	 *
	 * @since 1.3
	 */
	public static function changelog() {
		require_once plugin_dir_path( __FILE__ ) . 'partials/changelog.php';
	}

}
