<?php

/**
 * The core plugin class
 */
class Adsanity_ABD {

	/**
	 * The loader responsible for maintaining and registering all hooks that power the plugin
	 */
	protected $loader;

	/**
	 * Unique identifier
	 */
	protected $plugin_name;

	/**
	 * The version for this plugin
	 */
	protected $version;

	/**
	 * The core functionality
	 */
	public function __construct() {

		$this->plugin_name = 'adsanity_abd';
		$this->version = '1.1';

		$this->load_dependencies();
		$this->define_admin_hooks();
		$this->define_public_hooks();

	}

	/**
	 * Load the depencies for this plugin
	 */
	private function load_dependencies() {

		/**
		 * Class responsible for orchestrating the actions and filters of the core plugin
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-adsanity-abd-loader.php';

		/**
		 * Class responsible for defining internationalization functionality
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-adsanity-abd-i18n.php';

		/**
		 * Class responsible for defining all actions that occur in the public-facing side
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'public/class-adsanity-abd-public.php';

		/**
		 * Class responsible for defining actions for the admin area
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/class-adsanity-abd-admin.php';

		$this->loader = new Adsanity_ABD_Loader();
	}

	/**
	 * Define the locale for this plugin for internationalization.
	 */
	private function set_locale() {

		$plugin_i18n = new AdsanityABD_i18n();
		$this->loader->add_action( 'plugins_loaded', $plugin_i18n, 'load_plugin_textdomain' );

	}

	/**
	 * Register hooks related to the admin-area
	 *
	 * Adsanity_ABD_Loader - Orchestrates the hooks of the plugin
	 */
	private function define_admin_hooks() {

		$plugin_admin = new Adsanity_ABD_Admin( $this->get_plugin_name(), $this->get_version() );

		$this->loader->add_action( 'adsanity-addons', $plugin_admin, 'add_settings_tab' );
		$this->loader->add_action( 'admin_init', $plugin_admin, 'register_settings' );
		$this->loader->add_action( 'admin_init', $plugin_admin, 'register_sections' );
		$this->loader->add_action( 'admin_init', $plugin_admin, 'register_fields' );
		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_script' );
		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_style' );
		$this->loader->add_action( 'adsanity_changelog_screen', $plugin_admin, 'changelog' );

	}

	/**
	 * Register public-facing hooks
	 */
	private function define_public_hooks() {

		/**
		 * Create new instance of public class for the plugin
		 */
		$plugin_public = new Adsanity_ABD_Public( $this->get_plugin_name(), $this->get_version() );

		$this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_ad_script' );
		$this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_detection_script' );

		$this->loader->add_filter( 'the_content', $plugin_public, 'link_back' );

	}

	/**
	 * Run the loader to execute all hooks
	 */
	public function run() {

		return $this->loader->run();

	}

	/**
	 * Retrieve the plugin name
	 */
	public function get_plugin_name() {

		return $this->plugin_name;

	}

	/**
	 * Reference to the class that orchestrates the hooks
	 */
	public function get_loader() {

		return $this->loader;

	}

	/**
	 * Retrieve the version number
	 */
	public function get_version() {

		return $this->version;

	}
}
