<?php

/**
 * Public facing functionality
 */
class Adsanity_ABD_Public {

	/**
	 * Unique identifier
	 */
	private $plugin_name;

	/**
	 * The version for this plugin
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Enqueue the scripts for creating an ad
	 */
	public function enqueue_ad_script() {

		global $post;

		if ( ! isset( $post ) ) {
			return;
		}

		$options = get_option( 'adsanity-ad-block-detection-options' );

		if ( is_array( $options['post_type'] ) ) {
			if ( in_array( $post->post_type, $options['post_type'] ) ) {
				wp_enqueue_script( $this->plugin_name . '-ad', plugin_dir_url( __FILE__ ) . 'js/ads.js', array(), $this->version, true );
			}
		}

	}

	/**
	 * Enqueue the scripts for ad block detection
	 */
	public function enqueue_detection_script() {

		global $post;

		if ( ! isset( $post ) ) {
			return;
		}

		$options = get_option( 'adsanity-ad-block-detection-options' );

		if ( $post->guid === $options['redirect_page'] ) {
			return;
		}

		if ( is_array( $options['post_type'] ) ) {
			if ( in_array( $post->post_type, $options['post_type'] ) ) {

				wp_enqueue_script( $this->plugin_name . '-detector', plugin_dir_url( __FILE__ ) . 'js/detector.js', array(), $this->version, true );

				// Localize options variables
				wp_localize_script( $this->plugin_name . '-detector', 'adsanity_ad_block_vars', $options );

			}
		}
	}

	/**
	 * Add link back to the content
	 */
	public function link_back( $content ) {

		global $post;

		if ( ! isset( $post ) ) {
			return;
		}

		$options = get_option( 'adsanity-ad-block-detection-options' );

		if ( $post->guid === $options['redirect_page'] && isset( $_POST['link_back'] )) {

			// Sanitize the url
			$link_back = esc_url( $_POST['link_back'] );

			$link = sprintf( '<a href="%s">%s</a>',
				esc_attr( $link_back ),
				esc_html( $options['link_back'] )
			);

			return $content . $link;

		}

		return $content;

	}
}
