<?php

/**
 * Fired during plugin activation
 *
 * @link       https://www.pixeljar.com
 * @since      1.0.0
 *
 * @package    Adsanity_AR
 * @subpackage Adsanity_AR/includes
 */

/**
 * Fired during plugin activation.
 *
 * This class defines all code necessary to run during the plugin's activation.
 *
 * @since      1.0.0
 * @package    Adsanity_AR
 * @subpackage Adsanity_AR/includes
 * @author     Pixel Jar <info@pixeljar.com>
 */
class Adsanity_AR_Activator {

	/**
	 * Fired during plugin activation.
	 *
	 * @since    1.0.0
	 */
	public static function activate() {

		$capabilities = array(
			'level_0'               => true,
			'view_own_adsanity_ads' => true,
		);

		// Create an advertiser user role on activation
		add_role( 'advertiser', __( 'Advertiser', 'adsanity-ar' ), $capabilities );

		// Set some default options
		$options = array(
			'default-name'   => esc_html__( 'Advertiser', 'adsanity-ar' ),
			'email-subject'  => esc_html__( 'Your Ad Is About To Expire', 'adsanity-ar' ),
			'timing'         => 5,
			'email-template' => sprintf(
				esc_html__( 'Hello %s,

Your Ad, "%s" is set to expire in %s days, on %s.', 'adsanity-ar' ),
				'*|NAME|*',
				'*|AD|*',
				'*|DAYS|*',
				'*|DATE|*'
			),
		);

		add_option( 'adsanity-advertiser-reporting-options', $options );

	}

}
