<?php
if ( ! defined( 'ABSPATH' ) ) { die( 'You are not allowed to call this file directly.' ); }

// load our custom updater
if ( ! class_exists( 'EDD_SL_Plugin_Updater' ) ) {
	include( dirname( __FILE__ ) . '/EDD_SL_Plugin_Updater.php' );
}

class AdsanityARUpdater {

	static $file;
	const PRODUCT = 'Advertiser Reporting';
	const PRODUCT_ID = 6856;
	const SECTION = 'adsanity-ar-licenses';
	const KEY = 'adsanity_ar_license_key';
	const STATUS = 'adsanity_ar_license_status';
	const NONCE = 'adsanity_ar_license_nonce';
	const ACTIVATE = 'adsanity_ar_license_activate';
	const DEACTIVATE = 'adsanity_ar_license_deactivate';

	public static function hooks() {

		self::$file = ADSANITY_AR_ABS . 'adsanity-advertiser-reporting.php';

		add_action( 'admin_init', array( __CLASS__, 'plugin_updater' ), 0 );
		add_action( 'admin_init', array( __CLASS__, 'activate_license' ) );
		add_action( 'admin_init', array( __CLASS__, 'deactivate_license' ) );
		add_action( 'admin_init', array( __CLASS__, 'register_option' ) );

	}

	/**
	 * Loads EDD Updater class and checks for updates
	 */
	public static function plugin_updater() {

		// retrieve our license key from the DB
		$license_key = trim( get_option( self::KEY ) );

		// setup the updater
		$edd_updater = new EDD_SL_Plugin_Updater( ADSANITY_UPDATE_API, self::$file, array(
				'version' => '1.4', // current version number
				'license' => $license_key, // license key (used get_option above to retrieve from DB)
				'item_id' => self::PRODUCT_ID, // id of this plugin
				'author' => 'Pixel Jar' // author of this plugin
			)
		);
	}

	// creates our settings in the options table
	public static function register_option() {

		$license = get_option( self::KEY );
		$status = get_option( self::STATUS );
		$active = sprintf(
			'<span style="color:green;">%s</span>',
			__( 'active', 'adsanity' )
		);
		$inactive = sprintf(
			'<span style="color:red;">%s</span>',
			__( 'inactive', 'adsanity' )
		);

		register_setting(
			'adsanity-licenses',
			self::KEY,
			array( __CLASS__, 'sanitize_license' )
		);

		add_settings_section(
			self::SECTION, // section name
			'AdSanity Advertiser Reporting License',
			array( __CLASS__, 'license_description' ),
			'adsanity-licenses' // page
		);
			add_settings_field(
				'adsanity_license_key', // field name
				sprintf(
					'%s %s',
					__( 'License', 'adsanity' ),
					( empty( $license ) ) ? '' : ( ( $status !== false && $status == 'valid' ) ? '(' . $active . ')' : '(' . $inactive . ')' )
				),
				array( __CLASS__, 'key_field' ),
				'adsanity-licenses', // page
				self::SECTION // section name
			);
	}

	public static function license_description() {
		echo '<p>';
		echo sprintf(
			__( 'Enter your license for the %s add-on in the field below.', 'adsanity' ),
			'AdSanity Advertiser Reporting'
		);
		echo '</p>';
	}

	public static function key_field() {
		$license 	= get_option( self::KEY );
		$status 	= get_option( self::STATUS );

		echo sprintf(
			'<input id="%s" name="%s" type="text" class="regular-text" value="%s" />',
			self::KEY,
			self::KEY,
			esc_attr( $license )
		);

		if ( ! empty( $license ) ) {

			if ( $status !== false && $status == 'valid' ) {
				wp_nonce_field( self::NONCE, self::NONCE );
				echo sprintf(
					'<input type="submit" class="button-secondary" name="%s" value="%s"/>',
					self::DEACTIVATE,
					__( 'Deactivate License', 'adsanity' )
				);
			} else {
				wp_nonce_field( self::NONCE, self::NONCE );
				echo sprintf(
					'<input type="submit" class="button-secondary" name="%s" value="%s"/>',
					self::ACTIVATE,
					__( 'Activate License', 'adsanity' )
				);
			}
		}
	}

	public static function sanitize_license( $new ) {
		$old = get_option( self::KEY );
		if ( $old && $old != $new ) {
			delete_option( self::STATUS ); // new license has been entered, so must reactivate
		}
		return $new;
	}

	/**
	 * activates a license key
	 */
	public static function activate_license() {

		// listen for our activate button to be clicked
		if ( isset( $_POST[self::ACTIVATE] ) ) {

			// run a quick security check
		 	if ( ! check_admin_referer( self::NONCE, self::NONCE ) ) {
				return; // get out if we didn't click the Activate button
		 	}

			// retrieve the license from the database
			$license = trim( get_option( self::KEY ) );

			// data to send in our API request
			$api_params = array(
				'edd_action' => 'activate_license',
				'license' => $license,
				'item_id' => urlencode( self::PRODUCT_ID ), // the name of our product in EDD
				'url' => home_url()
			);

			// Call the custom API.
			$response = wp_remote_post(
				ADSANITY_UPDATE_API,
				array( 'timeout' => 15, 'sslverify' => false, 'body' => $api_params )
			);

			// make sure the response came back okay
			if ( is_wp_error( $response ) ) {
				return false;
			}

			// decode the license data
			$license_data = json_decode( wp_remote_retrieve_body( $response ) );

			update_option( self::STATUS, $license_data->license );

		}

	}

	/**
	 * This will descrease the site count
	 */
	public static function deactivate_license() {

		// listen for our activate button to be clicked
		if ( isset( $_POST[self::DEACTIVATE] ) ) {

			// run a quick security check
		 	if ( ! check_admin_referer( self::NONCE, self::NONCE ) ) {
				return; // get out if we didn't click the Activate button
		 	}

			// retrieve the license from the database
			$license = trim( get_option( self::KEY ) );

			// data to send in our API request
			$api_params = array(
				'edd_action'=> 'deactivate_license',
				'license' 	=> $license,
				'item_id' => urlencode( self::PRODUCT_ID ), // the name of our product in EDD
				'url'       => home_url()
			);

			// Call the custom API.
			$response = wp_remote_post(
				ADSANITY_UPDATE_API,
				array( 'timeout' => 15, 'sslverify' => false, 'body' => $api_params )
			);

			// make sure the response came back okay
			if ( is_wp_error( $response ) ) {
				return false;
			}

			// decode the license data
			$license_data = json_decode( wp_remote_retrieve_body( $response ) );
			if ( $license_data->license == 'deactivated' ) {
				delete_option( self::STATUS );
			}

		}

	}

}

AdsanityARUpdater::hooks();
