const inProduction = process.env.NODE_ENV === 'production';
const wpPot = require( 'wp-pot' );
const WebpackCleanPlugin = require( 'webpack-clean' );
const MiniCssExtractPlugin = require( 'mini-css-extract-plugin' );
const OptimizeCssAssetsPlugin = require( 'optimize-css-assets-webpack-plugin' );
const path = require( 'path' );

const entry = {
	'admin/dist/js/custom-reports'   : './admin/src/js/custom-reports',
	'admin/dist/css/admin-bar'       : './admin/src/css/admin-bar.scss',
	'admin/dist/css/taxonomy-styles' : './admin/src/css/taxonomy-styles.scss',

	'settings/dist/js/settings'      : './settings/src/js/index',
	'settings/dist/css/settings'     : './settings/src/css/styles.scss',
}

module.exports = {
	entry,
	output: {
		path: path.resolve( __dirname, './' ),
		filename: '[name].js',
	},
	module: {
		rules: [
			{
				test: /\.js$/,
				use: 'babel-loader',
			},
			{
				test: /\.(png|jpg|svg|eot|ttf|woff)$/,
				use: [
					{
						loader: 'url-loader', options: {
							limit: 10000
						},
					},
				],
			},
			{
				test: /\.(css|scss)$/,
				use: [
					MiniCssExtractPlugin.loader,
					{
						loader: 'css-loader',
					},
					'sass-loader',
				],
			},
			{
				test: /\.php$/,
				use: wpPot({
					destFile: 'languages/adsanity-ar.pot',
					domain: 'adsanity-ar',
					package: 'AdSanity - Advertiser Reporting',
				}),
			},
		],
		
	},
	plugins: [
		new MiniCssExtractPlugin({
			filename: "[name].css",
		}),
		new OptimizeCssAssetsPlugin(),
		new WebpackCleanPlugin(
			Object.keys( entry )
				.filter( ( key ) => key.includes( '/css/' ) )
				.map( ( key ) => key + '.js' )
		),
	],
	externals: [
		{
			jquery: 'window.jQuery',
		},
	],
	mode: inProduction ? 'production' : 'development',
}
