( function( $ ) {

/**
 * Handle condition change
 */
function handleConditionChange() {

	var condition = $( this ).val();

	// Hide the select and input
	var input = $( this ).nextAll( '.data' ).children( 'input[type="text"]' );
	input.hide();
	var select = $( this ).nextAll( '.data' ).children( 'select' );
	select.hide();

	// Is this an autocomplete field or select?
	if ( condition.substr( 0, 12 ) === 'autocomplete' ) {
		input.show();
		handleAutocomplete( this );
	} else {
		$( this ).nextAll( '.spinner' ).css( 'visibility', 'visible' );
		createOptions( this );
	}

	// Update names
	updateNames();

}

/**
 * Handle condition change on change and on load
 */
$( '#adsanity-caa' ).on( 'change', '.condition', handleConditionChange );
$( '#adsanity-caa .condition' ).each( handleConditionChange );

/**
 * Cache the data
 */
var dataCache = [];

/**
 * Create select inner HTML
 */
function createOptions( $this ) {

	var select = $( $this ).nextAll( '.data' ).children( 'select' );

	// Clear the current data select
	select.html( '' );

	var condition = $( $this ).val();

	// Check for cache
	if ( dataCache && dataCache[ condition ] ) {
		printOptions( dataCache[ condition ], $this );
		return;
	}

	// Get data from ajax endpoints
	$.ajax( {
		url: ajaxurl,
		data: {
			action: 'adsanity-caa_get_' + condition,
		},
		method: 'GET',
		success: function( response ) {
			printOptions( response.data, $this );
			// Store response in cache
			dataCache[ condition ] = response.data;

			// If data is not cached, it is the first
			// time to load. Check for data-value
			var existingValue = $( $this ).nextAll( '.data' ).data( 'value' );
			if ( existingValue ) {
				select.val( existingValue );
			}
		},
		error: function( err ) {
			console.log( 'Error: ' + err );
		},
	} );

}

/**
 * Print the options
 */
function printOptions( data, $this ) {

	// Show the select and hide the spinner
	$( $this ).nextAll( '.data' ).children( 'select' ).show();
	$( $this ).nextAll( '.spinner' ).css( 'visibility', 'hidden' );

	// Check if this data is an optgroup
	if ( data[0] == 'optgroup' ) {
		for ( var optgroupName in data ) {
			// Don't do anything with the first
			if ( optgroupName == 0 ) {
				continue;
			}
			var options = '';
			// Add options to the optgroup
			for ( var option in data[ optgroupName ] ) {
				// Construct the option and append it to the next data
				options += '<option value="' + option + '">' + data[ optgroupName ][ option ] + '</option>';
			}
			var optgroupMarkup = '<optgroup label="' + optgroupName + '">' + options + '</optgroup>';
			// Append the optgroup to the data select input
			$( $this ).nextAll( '.data' ).children( 'select' ).append( optgroupMarkup );
		}
	} else {
		// Create the option markup
		for ( var option in data ) {
			// Construct the option and append it to the next data
			var markup = '<option value="' + option + '">' + data[ option ] + '</option>';
			$( $this ).nextAll( '.data' ).children( 'select' ).append( markup );
		}
	}
	// Show the data input
	$( $this ).nextAll( '.data' ).css( 'display', 'inline-block' );
	$( $this ).nextAll( '.spinner' ).css( 'visibility', 'hidden' );
	// If disabled, return
	if ( $( '#adsanity-caa' ).hasClass( 'adsanity-caa-disabled' ) ) {
		return;
	}
	// Make select enabled
	$( $this ).attr( 'disabled', false );
	$( $this ).next().attr( 'disabled', false );

}

/**
 * Change the names of inputs
 */
function updateNames() {

	$( '#adsanity-caa .ruleset' ).each( function( index ) {
		$( this ).children( '.row' ).each( function( i ) {
			var namePrefix = 'caa-rules[' + index + '][' + i + ']'
			var condition = namePrefix + '[condition]';

			$( this ).children( '.condition' ).attr( 'name', condition );

			var bool = namePrefix + '[bool]';
			$( this ).children( '.bool' ).attr( 'name', bool );

			var data = namePrefix + '[data]';

			var conditionVal = $( this ).children( '.condition' ).val();

			if ( conditionVal.substr( 0, 12 ) == 'autocomplete' ) {
				$( this ).children( '.data' ).children( 'input[type="hidden"]' ).attr( 'name', data );
				$( this ).children( '.data' ).children( 'select' ).removeAttr( 'name' );
			} else {
				$( this ).children( '.data' ).children( 'select' ).attr( 'name', data );
				$( this ).children( '.data' ).children( 'input[type="hidden"]' ).removeAttr( 'name' );
			}

		} )
	} );

}

// Update names on load
updateNames();

/**
 * Handle Autocomplete
 */
function handleAutocomplete( $this ) {

	var data = $( $this ).nextAll( '.data' );

	var postData = {};

	if ( $( $this ).val().substr( 0, 17 ) === 'autocomplete_post' ) {
		var action = 'adsanity-caa_' + $( $this ).val().substr( 0, 17 );
		var postType = $( $this ).val().substr( 18 );
	} else if ( $( $this ).val().substr( 0, 17 ) === 'autocomplete_user' ) {
		var action = 'adsanity-caa_autocomplete_user';
		var postType = null;
	} else if ( $( $this ).val().substr( 0, 21 ) === 'autocomplete_taxonomy' ) {
		var action = 'adsanity-caa_autocomplete_term';
		var postType = null;
	}

	data.children( 'input[type="text"]' ).autocomplete( {
		source: function( request, response ) {
			$.ajax( {
				url: ajaxurl,
				data: {
					action       : action,
					post_type    : postType,
					autocomplete : request.term,
				},
				method: 'GET',
				success: function( json ) {
					response( json.data );
				},
			} );
		},
		select: function( event, ui ) {
			// On select, change hidden input to post id
			data.children( 'input[type="hidden"]' ).val( ui.item.id );
		},
	} );

}

/**
 * Add a row
 */
$( '#adsanity-caa' ).on( 'click', '.and', function() {
	// If disabled, return
	if ( $( '#adsanity-caa' ).hasClass( 'adsanity-caa-disabled' ) ) {
		return;
	}
	// Create a new row
	var newRow = $( '<div>' ).append( $( '#adsanity-caa .row' ).html() ).addClass( 'row' );
	// Get the new index
	var newIndex = $( '#adsanity-caa .row' ).length;

	// Change the condition to post_type
	newRow.children( '.condition' ).val( 'post_type' );

	// Clear the inputs
	newRow.find( 'input[type="text"]' ).val( '' );
	newRow.find( 'input[type="hidden"]' ).val( '' );

	// Call handleConditionChange and reference new row's condition as 'this'
	handleConditionChange.call( newRow.children( '.condition' ) );

	// Append the row to the ruleset
	$( this ).closest( '.ruleset' ).append( newRow );
	// Update row indexes
	updateNames();
} );

/**
 * Remove a row
 */
$( '#adsanity-caa' ).on( 'click', '.remove', function() {
	// If disabled, return
	if ( $( '#adsanity-caa' ).hasClass( 'adsanity-caa-disabled' ) ) {
		return;
	}
	// Get the closest row
	var row = $( this ).closest( '.row' );

	// Remove the ruleset if last row within
	if ( row.parent().children( '.row' ).length == 1 ) {
		// Remove the 'or' button and the ruleset element
		row.parent().next().remove();
		row.parent().remove();
		// Add the 'button' class to the last or element
		$( '#adsanity-caa .or' ).last().addClass( 'button' );
	} else {
		row.remove();
	}

	// Update row indexes
	updateNames();
} );

/**
 * Turn conditional ads on and off
 */
function conditionalAdsSwitch() {

	if( $( '#adsanity-caa-switch' ).is( ':checked' ) ) {
		$( '#adsanity-caa' ).removeClass( 'adsanity-caa-disabled' );
		// Enable all select inputs
		$( '#adsanity-caa select, #adsanity-caa input[type="text"]' ).each( function() {
			$( this ).attr( 'disabled', false );
		} );
		// Enable all buttons
		$( '#adsanity-caa .button' ).each( function() {
			$( this ).removeClass( 'disabled' );
		} );
	} else {
		$( '#adsanity-caa' ).addClass( 'adsanity-caa-disabled' );
		// Disable all select inputs
		$( '#adsanity-caa select, #adsanity-caa input[type="text"]' ).each( function() {
			$( this ).attr( 'disabled', true );
		} );
		// Disable all buttons
		$( '#adsanity-caa .button' ).each( function() {
			$( this ).addClass( 'disabled' );
		} );
	}
}
conditionalAdsSwitch();
$( '#adsanity-caa-switch' ).change( conditionalAdsSwitch );

/**
 * Add an 'or' condition
 */
$( '#adsanity-caa' ).on( 'click', '.or', function() {
	// If disabled, return
	if ( $( '#adsanity-caa' ).hasClass( 'adsanity-caa-disabled' ) ) {
		return;
	}
	// If no button class, return
	if ( ! $( this ).hasClass( 'button' ) ) {
		return;
	}
	$( this ).removeClass( 'button' );
	// Create a new rulset element and 'or' button
	var ruleset = $( '<div>' ).addClass( 'ruleset' );
	var newRow = $( '<div>' ).append( $( '#adsanity-caa .row' ).html() ).addClass( 'row' );
	newRow.children( '.condition' ).val( 'post_type' );
	ruleset.append( newRow );

	// Clear the inputs
	newRow.find( 'input[type="text"]' ).val( '' );
	newRow.find( 'input[type="hidden"]' ).val( '' );

	// Call handleConditionChange and reference new row's condition as 'this'
	handleConditionChange.call( newRow.children( '.condition' ) );

	var orButton = $( '#adsanity-caa .or' ).first().clone().addClass( 'button' );

	$( '#adsanity-caa .inside' ).append( ruleset, orButton );

	// Update row indexes
	updateNames();

} );

/**
 * Dismiss plugin compatibility warning
 */
$( '.adsanity-caa-plugin-compatibility' ).on( 'click', 'button', function() {
	$.ajax( {
		url: ajaxurl,
		data: {
			action: 'adsanity-caa_dismiss_plugin_compatibility',
		},
		method: 'GET'
	} );
} );

} )( jQuery );
