<?php
/*
Plugin Name: AdSanity - Custom Ad Sizes
Description: Allows an administrator to modify the default ad sizes that ship with AdSanity.
Plugin URI: http://adsanityplugin.com
Author: Pixel Jar
Author URI: http://www.pixeljar.com
Version: 1.5.1
License: GPL2
Text Domain: adsanity-cas
Domain Path: /lang

    Copyright (C) Jul 23, 2017  Pixel Jar  info@pixeljar.com

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2, as
    published by the Free Software Foundation.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

// If this file is called directly, abort.
if ( ! defined( 'ABSPATH' ) ) { die( 'You are not allowed to call this file directly.' ); }

// SET UP PATH CONSTANTS.
define( 'ADSANITY_CAS', 'adsanity-cas' );
define( 'ADSANITY_CAS_VERSION', '1.5.1' );
define( 'ADSANITY_CAS_URL', plugin_dir_url( __FILE__ ) );
define( 'ADSANITY_CAS_ABS', plugin_dir_path( __FILE__ ) );
define( 'ADSANITY_CAS_SLUG', plugin_basename( __FILE__ ) );
define( 'ADSANITY_CAS_REL', basename( dirname( __FILE__ ) ) );
define( 'ADSANITY_CAS_VIEWS', ADSANITY_CAS_ABS . 'views/' );
define( 'ADSANITY_CAS_CSS', ADSANITY_CAS_URL . 'css/' );
define( 'ADSANITY_CAS_JS', ADSANITY_CAS_URL . 'js/' );
define( 'ADSANITY_CAS_ADMIN_OPTIONS', 'adsanity-options' );

// Update API.
require ADSANITY_CAS_ABS . 'update-engine/remote-api.php';

/**
 * The main plugin class
 */
class AdSanity_Custom_Ad_Sizes {

	/**
	 * AdSanity Core option name.
	 *
	 * @var string
	 */
	public static $option_name = 'adsanity-options';

	/**
	 * The transient name.
	 *
	 * @var string
	 */
	public static $transient_name = 'adsanity-cas-transient';

	/**
	 * There are two examples here:
	 * 1. overwrite the built-in sizes (a.k.a. substitute your own reality)
	 * 2. add a size to the built-in sizes (a.k.a. augment reality)
	 *
	 * Simply uncomment and modify the style that fits your needs. Enjoy! =)
	 */
	public static function hooks() {

		add_action( 'plugins_loaded', array( __CLASS__, 'load_textdomain' ) );
		add_action( 'admin_menu', array( __CLASS__, 'admin_menu' ) );
		add_action( 'admin_enqueue_scripts', array( __CLASS__, 'register_scripts' ), 1 );
		add_action( 'admin_enqueue_scripts', array( __CLASS__, 'enqueue_scripts' ), 10 );
		add_action( 'admin_init', array( __CLASS__, 'update_option' ) );
		add_action( 'admin_init', array( __CLASS__, 'plugin_update' ) );
		add_action( 'enqueue_block_editor_assets', array( __CLASS__, 'backend_styles' ), 20 );
		add_action( 'admin_enqueue_scripts', array( __CLASS__, 'backend_styles' ) );
		add_action( 'adsanity_changelog_screen', array( __CLASS__, 'changelog' ) );
		add_action( 'init', [ __CLASS__, 'endpoint' ] );
		add_action( 'template_redirect', [ __CLASS__, 'redirect' ] );
		add_action( 'wp_enqueue_scripts', [ __CLASS__, 'frontend_styles' ] );

	}

	/**
	 * Loads translations.
	 *
	 * @return void
	 */
	public static function load_textdomain() {

		load_plugin_textdomain(
			'adsanity-cas',
			false,
			dirname( plugin_basename( __FILE__ ) ) . '/lang'
		);

	}

	/**
	 * Creates an admin page for Custom Ad Sizes.
	 *
	 * @return void
	 */
	public static function admin_menu() {

		add_submenu_page(
			'edit.php?post_type=ads',
			'AdSanity: ' . __( 'Custom Ad Sizes', 'adsanity-cas' ),
			__( 'Custom Ad Sizes', 'adsanity-cas' ),
			'manage_options',
			'custom-ad-sizes',
			array( __CLASS__, 'custom_ad_sizes_screen' )
		);

	}

	/**
	 * Renders the Custom Ad Sizes admin page.
	 *
	 * @return void
	 */
	public static function custom_ad_sizes_screen() {

		require_once ADSANITY_CAS_VIEWS . 'custom-ad-sizes.php';

	}

	/**
	 * Register scripts and styles for use with the plugin.
	 *
	 * @return void
	 */
	public static function register_scripts() {

		if ( 'development' ===  wp_get_environment_type() ) {
			$version = time();
		} else {
			$version = ADSANITY_CAS_VERSION;
		}

		wp_register_script(
			'adsanity-custom-ad-sizes',
			ADSANITY_CAS_JS . 'custom-ad-sizes.js',
			array( 'jquery' ),
			$version,
			true
		);

		wp_register_style(
			'adsanity-custom-ad-sizes',
			ADSANITY_CAS_CSS . 'custom-ad-sizes.css',
			array(),
			$version
		);

	}

	/**
	 * Enqueues scripts in the dashboard.
	 *
	 * @param string $hook The the slug for the page.
	 * @return void
	 */
	public static function enqueue_scripts( $hook = '' ) {

		if ( 'ads_page_custom-ad-sizes' !== $hook ) {
			return;
		}

		wp_enqueue_style( 'adsanity-custom-ad-sizes' );
		wp_enqueue_script( 'adsanity-custom-ad-sizes' );

	}

	/**
	 * Output the list of Custom Ad Sizes.
	 *
	 * @return void
	 */
	public static function custom_ad_sizes() {

		// Echo out a template.
		?>
		<tr class="template">
			<td>
				<input
					class="label"
					type="text"
					value="<?php esc_attr_e( 'Enter a size name...', 'adsanity-cas' ); ?>"
					data-name="<?php echo esc_attr( self::$option_name ) . '[sizes][]'; ?>"
				/>
			</td>
			<td><input min="1" class="width" type="number" value="1"/></td>
			<td><input min="1" class="height" type="number" value="1"/></td>
			<td>
				<button class="remove-size">
					<span class="dashicons dashicons-trash"></span>
				</button>
			</td>
		</tr>
		<?php

		$template = '<tr>
			<td><input class="label" type="text" value="%1$s" name="%4$s[%5$s]"/></td>
			<td><input min="1" class="width" type="number" value="%2$s"/></td>
			<td><input min="1" class="height" type="number" value="%3$s"/></td>
			<td>
				<button class="remove-size">
					<span class="dashicons dashicons-trash"></span>
				</button>
			</td>
		</tr>';

		$options = get_option( self::$option_name );

		if ( ! $options || ! isset( $options['sizes'] ) ) {
			return;
		}

		$sizes = $options['sizes'];

		foreach ( $sizes as $value => $label ) {

			$split = explode( 'x', $value );

			if ( 2 !== count( $split ) ) {
				continue;
			}

			printf(
				$template,
				esc_attr( $label ),
				esc_attr( $split[0] ),
				esc_attr( $split[1] ),
				esc_attr( self::$option_name . '[sizes]' ),
				esc_attr( $value )
			);
		}

	}

	/**
	 * Update the ad sizes value.
	 *
	 * @return void
	 */
	public static function update_option() {

		if ( ! isset( $_POST ) ||
			 ! isset( $_POST['action'] ) ||
			 'save-adsanity-custom-sizes' !== $_POST['action'] ||
			 ! isset( $_POST[ self::$option_name ] ) ||
			 ! isset( $_POST[ self::$option_name ]['sizes'] ) ) {
			return;
		}

		$adsanity_options = get_option( self::$option_name, array() );

		$new_sizes = array();

		foreach ( $_POST[ self::$option_name ]['sizes'] as $key => $value ) {

			if ( ! $key ) {
				continue;
			}

			$key               = sanitize_text_field( $key );
			$value             = sanitize_text_field( $value );
			$new_sizes[ $key ] = $value;
		}

		$adsanity_options['sizes'] = $new_sizes;

		// Remove the transient for styles.
		delete_transient( self::$transient_name );

		update_option( self::$option_name, $adsanity_options );

	}

	/**
	 * Get the custom css rules for ad sizes, with transient handling.
	 *
	 * @return string $css Custom css for this plugin.
	 */
	private static function get_custom_css() {
		$css = get_transient( self::$transient_name );
		if ( ! $css ) {
			$css = self::generate_custom_css();
			set_transient( self::$transient_name, $css, DAY_IN_SECONDS );
		}
		$css = apply_filters( 'adsanity_cas_custom_css', $css );
		return $css;
	}

	/**
	 * Generates CSS
	 *
	 * @return string $css Custom css for this plugin.
	 */
	private static function generate_custom_css() {
		$options = get_option( self::$option_name );

		if ( ! isset( $options['sizes'] ) ) {
			return '';
		}

		$all_ad_sizes     = $options['sizes'];
		$default_ad_sizes = [];

		if ( defined( 'ADSANITY_DEFAULT_AD_SIZES' ) ) {
			$default_ad_sizes = ADSANITY_DEFAULT_AD_SIZES;
		}

		$custom_ad_sizes = array_diff( $all_ad_sizes, $default_ad_sizes );

		if ( ! is_array( $custom_ad_sizes ) || empty( $custom_ad_sizes ) ) {
			return '';
		}

		$custom_css = '';

		foreach ( $custom_ad_sizes as $size => $value ) {

			$dimensions = explode( 'x', $size );
			if ( count( $dimensions ) !== 2 ) {
				continue;
			}

			$width  = intval( $dimensions[0] );
			$height = intval( $dimensions[1] );

			if ( 0 === $width || 0 === $height ) {
				continue;
			}

			// Refer to widget-default.css in AdSanity Core.
			$custom_css .= sprintf(
				'.ad-%1$s {
					height: auto;
					max-width: %2$spx;
					max-height: %3$spx;
					position: relative;
					width: 100%%;
				}
				.ad-%1$s .adsanity-inner {
					height: 0;
					padding-bottom: %4$s%%;
					width: 100%%;
				}
				.ad-%1$s .adsanity-inner iframe {
					height: 100%%;
					left: 0;
					position: absolute;
					top: 0;
					width: 100%%;
				}
				.ad-%1$s .adsanity-inner img {
					height: auto;
					width: 100%%;
				}',
				$size,
				$width,
				$height,
				round( ( $height / $width * 100 ), 2 )
			);

		}

		// Minimize styles.
		$custom_css = str_replace( ': ', ':', $custom_css );
		$custom_css = str_replace( ' {', '{', $custom_css );
		return preg_replace( '/(\t|\n)/', '', $custom_css );
	}

	/**
	 * Print styles for custom ad sizes within the block editor and ad edit screens.
	 *
	 * @return void
	 */
	public static function backend_styles() {

		$custom_css = self::get_custom_css();
		if ( ! $custom_css ) {
			return;
		}

		wp_add_inline_style( 'adsanity-blocks-widget-default', $custom_css );

		if ( ! function_exists( 'get_current_screen' ) ) {
			return;
		}

		$screen = get_current_screen();

		if ( 'ads' !== $screen->post_type || 'post' !== $screen->base ) {
			return;
		}

		wp_add_inline_style( 'adsanity-post', $custom_css );

	}

	/**
	 * Adds frontend styles for custom sizes.
	 *
	 * @return void
	 */
	public static function frontend_styles() {

		if ( 'development' ===  wp_get_environment_type() ) {
			$version = time();
		} else {
			$version = ADSANITY_CAS_VERSION;
		}

		wp_enqueue_style(
			ADSANITY_CAS,
			trailingslashit( site_url( 'cas-custom-sizes' ) ),
			[],
			$version,
			'all'
		);
	}

	/**
	 * Adds the changelog to AdSanity's main changelog page.
	 *
	 * @since 1.3
	 * @return void
	 */
	public static function changelog() {
		require_once ADSANITY_CAS_VIEWS . 'changelog.php';
	}

	/**
	 * Set up the rewrite rules for the custom endpoint.
	 *
	 * @return void
	 */
	public static function activation() {

		self::endpoint();

		// ATTENTION: This is *only* done during plugin activation hook!
		// You should *NEVER EVER* do this on every page load!!
		flush_rewrite_rules();

	}

	/**
	 * Remove the rewrite rules for the custom endpoint.
	 *
	 * @return void
	 */
	public static function deactivation() {

		// ATTENTION: This is *only* done during plugin deactivation hook!
		// You should *NEVER EVER* do this on every page load!!
		flush_rewrite_rules();

	}

	/**
	 * Adds endpoint for custom ad size CSS.
	 *
	 * @return void
	 */
	public static function endpoint() {

		add_rewrite_endpoint( 'cas-custom-sizes', EP_ROOT );

	}

	/**
	 * Renders custom ad size CSS.
	 *
	 * @return void
	 */
	public static function redirect() {

		global $wp_query;

		if ( ! isset( $wp_query->query_vars['cas-custom-sizes'] ) ) {
			return;
		}

		$custom_css = self::get_custom_css();
		if ( ! $custom_css ) {
			exit;
		}

		header( 'Content-Type: text/css' );

		echo $custom_css;

		exit;

	}

	/**
	 * Run updates if necessary.
	 *
	 * @return void
	 */
	public static function plugin_update() {

		$local_version = get_option( 'adsanity-cas-db-version', false );
		if ( false === $local_version ) {

			// Update permalinks.
			self::activation();

			// New Install.
			update_option( 'adsanity-cas-db-version', ADSANITY_CAS_VERSION );
			return;

		} elseif ( version_compare( $local_version, ADSANITY_VERSION, '>=' ) ) {

			// This or Beta Version.
			return;

		}

		// VERSION 1.5.1 Upgrade Routines.
		if ( version_compare( $local_version, '1.5.1', '<' ) ) {

			// Update permalinks.
			self::activation();

		}

		// The last step is to update the DB Version.
		update_option( 'adsanity-cas-db-version', ADSANITY_VERSION );

	}

}
AdSanity_Custom_Ad_Sizes::hooks();


register_activation_hook( __FILE__, array( 'AdSanity_Custom_Ad_Sizes', 'activation' ) );
register_deactivation_hook( __FILE__, array( 'AdSanity_Custom_Ad_Sizes', 'deactivation' ) );
