<?php

/**
 * Admin plugin functionality
 */
class Adsanity_GATI_Admin {

	/**
	 * Unique identifier
	 */
	private $plugin_name;

	/**
	 * The Plugin Options
	 */
	private $options;

	/**
	 * The version for this plugin
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;
		$this->set_options();
	}

	/**
	 * Admin area scripts
	 */
	public function enqueue_script( $hook ) {

		// Register Vue and Vue Resource
		wp_register_script( 'vue', plugin_dir_url( __FILE__ ) . 'js/vue/vue.min.js', array(), $this->version, true );
		wp_register_script( 'vue-resource', plugin_dir_url( __FILE__ ) . 'js/vue/vue-resource.min.js', array( 'vue' ), $this->version, true );

		// Enqueue setup page scripts
		if ( $hook === 'ads_page_adsanity-settings' ) {
			wp_enqueue_script( $this->plugin_name . '-setup', plugin_dir_url( __FILE__ ) . 'js/adsanity-gati-admin-setup.js', array( 'vue', 'vue-resource' ), $this->version, true );
		// Enqueue stats page scripts
		} else if ( $hook === 'ads_page_adsanity-offload-stats' ) {
			wp_enqueue_script( $this->plugin_name . '-reports', plugin_dir_url( __FILE__ ) . 'js/adsanity-gati-admin-reports.js', array( 'jquery', 'jquery-ui-datepicker' ), $this->version );
		}

		// Localize a variable to tell AdSanity Core not to plot charts
		wp_localize_script( 'adsanity-post', 'ADSANITY_DO_NOT_PLOT', array() );

	}

	/**
	 * Admin area styles
	 */
	public function enqueue_style( $hook = '' ) {

		// Enqueue the stats style from adsanity core
		if ( $hook === 'ads_page_adsanity-offload-stats' ) {
			wp_enqueue_style( $this->plugin_name . '-reports', plugin_dir_url( __FILE__ ) . 'css/reports.css', array( 'adsanity-jqueryui-datepicker' ), $this->version, 'screen' );
		// Enqueue Setup screen styles
		} elseif ( $hook === 'ads_page_adsanity-settings' ) {
			wp_enqueue_style( $this->plugin_name . '-setup', plugin_dir_url( __FILE__ ) . 'css/setup.css', array(), $this->version, 'screen' );
		}

	}

	/**
	 * Sets the class variable $options
	 */
	private function set_options() {

		$this->options = get_option( 'adsanity-google-analytics-tracking-integration-options' );

	}

	/**
	 * Add an add-on tab to AdSanity settings
	 */
	public function add_settings_tab( $addons = array() ) {

		$addons[] = array(
			'slug' => 'google-analytics-tracking-integration',
			'name' => __( 'Google Analytics Tracking Integration', 'adsanity-gati' ),
		);
		return $addons;

	}

	public function settings_section() {

		add_settings_section(
			'adsanity-google-analytics-tracking-integration-options',
			__( 'AdSanity Google Analytics Tracking Integration', 'adsanity-gati' ),
			array( $this, 'settings_section_view' ),
			$this->plugin_name . '-settings',
			'adsanity-options'
		);

	}

	/**
	 * Register plugin settings
	 */
	public function register_settings() {

		register_setting(
			$this->plugin_name . '-options',
			'adsanity-google-analytics-tracking-integration-options',
			array( $this, 'validate_options' )
		);

	}

	/**
	 * Register settings section
	 */
	public function register_sections() {

		add_settings_section(
			$this->plugin_name . '-tracking',
			__( 'AdSanity Google Analytics', 'adsanity-gati' ),
			array( $this, 'page_options' ),
			'adsanity-google-analytics-tracking-integration-options'
		);

	}

	/**
	 * Creates an options page
	 */
	public function page_options() {

		require_once( plugin_dir_path( __FILE__ ) . 'views/setup.php' );

	}

	/**
	 * Validate options input
	 *
	 * This function is a formality; everything
	 * handled in ajax and Vue
	 */
	public function validate_options( $input ) {

		return $input;

	}

	/**
	 * Add Google stats embed to AdSanity editor
	 */
	public function single_ad_charts() {

		global $post;

		if ( $post->post_status === 'publish' ) {

			add_meta_box( $this->plugin_name . '-google_stats',
				__( 'Google Analytics Stats', 'adsanity-gati' ),
				array( $this, 'single_ad_charts_cb' ),
				'ads',
				'normal',
				'low'
			);
		}
	}

	/**
	 * Callback for Google stats embed
	 */
	public function single_ad_charts_cb() {
		require_once( plugin_dir_path( __FILE__ ) . 'views/single-ad-charts.php' );
	}

	/**
	 * Display information on reports page
	 */
	public function reports_page() {
		require_once( plugin_dir_path( __FILE__ ) . 'views/reports-page.php' );
	}

	/**
	 * Helper function for sorting ad stats by clicks, high to low
	 */
	private function sort_by_clicks( $a, $b ) {
		if ( $a['click'] == $b['click'] ) {
			return 0;
		}

		return ( $a['click'] > $b['click'] ) ? -1 : 1;
	}

	/**
	 * Helper function for sorting ad stats by ctr, high to low
	 */
	private function sort_by_ctr( $a, $b ) {
		if ( $a['ctr'] == $b['ctr'] ) {
			return 0;
		}

		return ( $a['ctr'] > $b['ctr'] ) ? -1 : 1;
	}

	/**
	 * Remove single ad stats metabox
	 */
	public function remove_single_ad_stats() {

		remove_meta_box( 'ad-chart', 'ads', 'normal' );

	}

	/**
	 * Remove ad reports submenu page
	 */
	public function remove_ad_reports() {

		remove_submenu_page( 'edit.php?post_type=ads', 'adsanity-stats' );

	}

	/**
	 * Add a submenu page for our reports
	 */
	public function ad_reports_page() {

		add_submenu_page(
			'edit.php?post_type=ads',
			'AdSanity: ' . __( 'Reports', 'adsanity-gati' ),
			__( 'Reports', 'adsanity-gati' ),
			'adsanity_view_ad_stats',
			'adsanity-offload-stats',
			array( $this, 'reports_page_cb' )
		);

	}

	/**
	 * Callback for the reports page
	 */
	public function reports_page_cb() {

		require_once( plugin_dir_path( __FILE__ ) . 'views/reports-page.php' );

	}

	/**
	 * Rename Today's Stats column
	 */
	public function todays_stats_columns( $columns ) {

		$columns['adsanity-stats'] = __( 'Stats', 'adsanity-gati' );
		return $columns;

	}

	/**
	 * Change the display of Today's Stats column
	 */
	public function stats_column_value( $value, $column = '', $post_id = 1 ) {

		if ( 'adsanity-stats' == $column ) {
			$format = '<a href="%spost.php?post=%s&action=edit#adsanity_gati-google_stats">
				<span class="dashicons dashicons-chart-bar"></span>
			</a>
			';

			printf( $format,
				admin_url(),
				$post_id
			);
		}

	}

	/**
	 * Add an admin notice when Google Analytics must be configured
	 */
	public function configuration_admin_notice() {

		if ( ! current_user_can( 'manage_options' ) ) {
			return;
		}

		// Get the already tracking settings, the minimum setting
		$already_tracking = get_option( $this->plugin_name . '-already_tracking', 'unset' );

		if ( $already_tracking != 'unset' ) {
			return;
		}

		printf( '<div class="notice notice-warning is-dismissible"><p>%s <a href="%s">%s</a></p></div>',
			esc_html__( 'Please configure', 'adsanity-gati' ),
			admin_url() . 'edit.php?post_type=ads&page=adsanity-settings&tab=add-ons&sub=google-analytics-tracking-integration',
			esc_html__( 'AdSanity - Google Analytics Tracking Integration', 'adsanity-gati' )
		);

	}

	/**
	 * Admin notice for Monster Insights being activated
	 */
	public function monster_insights_activated_notice() {

		if ( ! current_user_can( 'manage_options' ) ) {
			return;
		}

		// See if Monster Insights is activated
		if ( ! function_exists( 'MonsterInsights' ) ) {
			return;
		}

		// See if we have the already tracking option set to false
		$already_tracking = get_option( $this->plugin_name . '-already_tracking', 'true' );

		if ( 'true' === $already_tracking ) {
			return;
		}

		$this->monster_insights_admin_notice();

	}

	/**
	 * Admin notice for Monster Insights being deactivated
	 */
	public function monster_insights_deactivated_notice() {

		if ( ! current_user_can( 'manage_options' ) ) {
			return;
		}

		// See if Monster Insights is activated
		if ( function_exists( 'MonsterInsights' ) ) {
			return;
		}

		$using_monster_insights = get_option( $this->plugin_name . '-using_monster_insights', false );

		if ( ! $using_monster_insights ) {
			return;
		}

		$this->monster_insights_admin_notice();

	}

	/**
	 * The markup for the admin notice
	 */
	public function monster_insights_admin_notice() {

		$plugin_name = sprintf( esc_html__( '%s - Google Analytics Tracking Integration', 'adsanity-gati' ),
			'AdSanity'
		);

		$plugin_auth_link = sprintf( '<a href="%s">%s</a>',
			admin_url() . 'edit.php?post_type=ads&page=adsanity-settings&tab=add-ons&sub=google-analytics-tracking-integration',
			$plugin_name
		);

		$warning_message = sprintf( 'We\'ve noticed a change in your Monster Insights configuration. Please re-authenticate %s to prevent tracking errors.',
			$plugin_auth_link
		);


		printf( '<div class="notice notice-warning is-dismissible"><p>%s</p></div>',
			wp_kses_post( $warning_message )
		);

	}

	/**
	 * Adds the changelog to AdSanity's main changelog page.
	 *
	 * @since 1.3
	 */
	public static function changelog() {
		require_once plugin_dir_path( __FILE__ ) . 'partials/changelog.php';
	}

}
