( function( $ ) {

$( document ).ready( function() {

	// Add the datepicker ui
	$( '#start-date, #end-date' ).datepicker( {
		changeMonth: true,
		changeYear: true,
		dateFormat: 'yy-mm-dd',
	} );

	// Show all/none ads checkboxes
	$( '.selectall' ).click( function() {
		$( '.ads-list input' ).each( function() {
			$( this ).prop( 'checked', 'checked' );
		} );
	} );

	$( '.selectnone' ).click( function() {
		$( '.ads-list input' ).each( function() {
			$( this ).removeProp( 'checked' );
		} );
	} );

	// Handle submit
	$( '#submit' ).click( function() {
		$( 'tbody' ).html( '' );
		var startDate = $( '#start-date' ).val();
		var endDate = $( '#end-date' ).val();
		var ads = [];

		// Remove inner content of single ad
		$( '#single-ad-chart-views' ).html( '' );
		$( '#single-ad-chart-clicks' ).html( '' );
		$( '.single-ad-charts' ).hide();

		// If only one ad, show a chart
		if ( $( '.ads-list input:checked' ).length === 1 ) {
			showSingleAdChart( $( '.ads-list input:checked' ).val() );
		}

		$( '.ads-list input:checked' ).each( function() {
			ads.push( $( this ).val() );
		} );

		var report = $.post( ajaxurl,
			{
				action: 'adsanity_gati_custom_reports',
				startDate: startDate,
				endDate: endDate,
				ads: ads,
			}
		);

		report.done( function( response ) {
			addTableRows( response.data );
		} );
	} );

	// Add table rows to custom report page
	function addTableRows( data ) {

		var totalViews = 0;
		var totalClicks = 0;

		for ( var date in data ) {

			for ( var title in data[ date ] ) {
				var row = data[ date ][ title ];
				var views = row.view ? row.view : 0;
				var clicks = row.click ? row.click : 0;
				var ctr = row.ctr ? row.ctr : 0;
				totalViews += parseInt( views );
				totalClicks += parseInt( clicks );

				var tableRow = '<tr><th>' + title + '</th><th>' + date + '</th><th>' + views + '</th><th>' + clicks + '</th><th>' + ctr + '%</th></tr>';

				$( 'tbody' ).append( tableRow );
			}
		}

		$( '#total-views' ).text( totalViews );
		$( '#total-clicks' ).text( totalClicks );
		$( '#total-ctr' ).text( Math.round( totalClicks / totalViews * 10000 ) / 100 + '%' );

	}

	// Create a CSV file for export
	function createCSV( e ) {
		e.preventDefault();

		// Return if there is no data
		if ( $( '#report-table tbody tr' ).length < 1 ) {
			return;
		}

		var data = statsArray();

		var csvContent = 'data:text/csv;charset=utf-8,';

		data.forEach( function( info, index ) {
			dataString = '"' + info.join( '","' ) + '"';
			csvContent += index < data.length ? dataString + '\n' : dataString;
		} );

		var encodedUri = encodeURI(csvContent);
		window.open(encodedUri);
	}

	// Prepare array for CSV export
	function statsArray() {
		var csv = [
			[ 'Title', 'Date', 'Views', 'Clicks', 'CTR %' ],
		];
		$( '#report-table tbody tr' ).each( function() {
			var row = [];

			$( this ).children( 'th' ).each( function() {
				row.push( $( this )[ 0 ].innerText );
			} );

			csv.push( row );
		} );

		var footer = [];

		$( '#report-table tfoot tr:first-child th' ).each( function() {
			footer.push( $( this )[ 0 ].innerText );
		} );

		csv.push( footer );

		return csv;
	}

	$( '#export-csv' ).click( createCSV );

	// If only one ad was selected, show a Google chart
	function showSingleAdChart( ad ) {

		gapi.analytics.ready( function() {

			gapi.analytics.auth.authorize( {
				'serverAuth' : {
					'access_token' : $( '.single-ad-charts' ).data( 'access' ),
				},
			} );

			var profile = $( '.single-ad-charts' ).data( 'profile' );

			var singleAdChartViews = new gapi.analytics.googleCharts.DataChart( {
				query : {
					'ids' : profile,
					'start-date' : $( '#start-date' ).val(),
					'end-date' : $( '#end-date' ).val(),
					'metrics' : 'ga:uniqueEvents,ga:totalEvents',
					'dimensions' : 'ga:date',
					'filters' : 'ga:eventCategory==AdSanity;ga:eventAction==view;ga:eventLabel==' + ad,
				},
				chart : {
					'container' : 'single-ad-chart-views',
					'type' : 'LINE',
					'options' : {
						'width' : '100%',
					},
				},
			} );

			singleAdChartViews.execute();

			var singleAdChartClicks = new gapi.analytics.googleCharts.DataChart( {
				query : {
					'ids' : profile,
					'start-date' : $( '#start-date' ).val(),
					'end-date' : $( '#end-date' ).val(),
					'metrics' : 'ga:uniqueEvents,ga:totalEvents',
					'dimensions' : 'ga:date',
					'filters' : 'ga:eventCategory==AdSanity;ga:eventAction==click;ga:eventLabel==' + ad,
				},
				chart : {
					'container' : 'single-ad-chart-clicks',
					'type' : 'LINE',
					'options' : {
						'width' : '100%',
					},
				},
			} );

			singleAdChartClicks.execute();

			$( '.single-ad-charts' ).show();

		} );
	}

	// Dismiss expectations warning
	$( 'body' ).on( 'click', '#adsanity-gati-expectation-warning button', function() {
		$.post( ajaxurl, {
			action: 'adsanity_gati_dismiss_expectation',
		} );
	} );

	/****************
	 * Group Ad Block
	 ***************/
	function getAds() {

		var termId = $( '#adsanity-ad-group-dashboard select' ).val();

		$( '#adsanity-ad-group-dashboard table' ).addClass( 'loading' );
		$( '#adsanity-ad-group-dashboard tbody' ).html( '<tr></tr>' );

		$.post( ajaxurl, {
			action  : 'adsanity_gati_get_ads_by_term',
			term_id : termId,
		} )
		.done( function( response ) {
			constructTable( response.data );
		} );

	}

	function constructTable( data ) {

		$( '#adsanity-ad-group-dashboard tbody' ).html( '' );
		$( '#adsanity-ad-group-dashboard table' ).removeClass( 'loading' );

		for ( var ad in data ) {

			var row = '<tr>';
				row += '<td><a href="' + data[ ad ].link + '">' + ad + '<a></td>';
				row += '<td>' + data[ ad ].view + '</td>';
				row += '<td>' + data[ ad].click + '</td>';
				row += '<td>' + data[ ad ].ctr + '</td>';
			row += '</tr>';

			$( '#adsanity-ad-group-dashboard tbody' ).append( row );
		}

	}

	$( '#adsanity-ad-group-dashboard select' ).change( getAds );

	getAds();

} );

} )( jQuery )
