/**
 * Handles user setup process
 */

( function() {
	var app = new Vue({
		el: '#app',

		data: {
			error: 					false,
			success: 				false,
			errorMessage: 			'Oops! Something went wrong',
			monsterInsights: 		false,
			askAlreadyTracking: 	false,
			authenticate: 			false,
			alreadyTracking: 		false,
			enterTrackingId: 		false,
			allowTrackingId: 		true,
			manualTrackingId: 		'',
			authenticateWithGoogle: false,
			authorizationCode: 		'',
			selectProfile: 			false,
			profiles: 				[],
			analyticsProfile: 		'',
			trackUsers: 			[],
			analyticsProperty:      '',
		},

		methods: {
			handleAlreadyTrackingContinueClick: function() {
				this.$http.post( ajaxurl,
					{
						action: 'adsanity_gati_already_tracking',
						alreadyTracking: this.alreadyTracking,
					}
				).then( function( response ) {
					this.askAlreadyTracking = false;
					this.authenticate = true;
					// If already tracking, do not allow user to enter tracking id
					if ( this.alreadyTracking ) {
						this.allowTrackingId = false;
					}
				}, function( err ) {
					app.error = true;
				} );
			},

			handleTrackingIdClick: function() {
				this.authenticateWithGoogle = false;
				this.enterTrackingId = true;
			},

			handleAuthenticateClick: function() {
				this.enterTrackingId = false;
				requestGoogleoAuthCode();
				this.authenticateWithGoogle = true;
			},

			handleAuthorizationCodeClick: function() {
				this.$http.post( ajaxurl,
					{
						action: 'adsanity_gati_authorization',
						authorization_code: this.authorizationCode,
					}
				).then( function( response ) {
					this.error = false;
					this.getProfiles();
				}, function( err ) {
					this.error = true;
				} );
			},

			getProfiles: function() {
				this.$http.post( ajaxurl,
					{
						action: 'adsanity_gati_get_profiles',
					}
				).then( function( response ) {
					this.profiles = response.body.data;
				}, function( err ) {
					this.error = true;
				} );
				this.selectProfile = true;
			},

			handleAuthorizationContinueClick: function() {
				// If we are using tracking id
				if ( this.enterTrackingId ) {
					// Return if tracking id is empty
					if ( ! this.trackingId ) {
						this.error = true;
						return;
					}
					this.error = false;
					this.$http.post( ajaxurl,
						{
							action: 'adsanity_gati_manual_tracking',
							trackingId: this.manualTrackingId,
						}
					).then( function( response ) {
						// Reload the page
						window.location.reload();
					}, function( err ) {
						this.error = true;
					} );
				} else {
					// If authorized through Google
					this.$http.post( ajaxurl,
						{
							action: 'adsanity_gati_set_profile',
							id: this.analyticsProperty.profiles[0].id,
							// tracking: this.analyticsProfile.tracking,
							tracking: this.analyticsProperty.id,
						}
					).then( function( response ) {
						// Reload the page
						window.location.reload();
					}, function( err ) {
						this.error = true;
					} );
				}
			},

			handleDeauthClick: function() {
				this.$http.post( ajaxurl,
					{
						action: 'adsanity_gati_remove_authentication',
					}
				).then( function( response ) {
					this.error = false;
					// Reload the page
					window.location.reload();
				}, function( err ) {
					this.error = true;
				} );
			},
		},

		computed: {

			analyticsProperties: function() {
				return this.analyticsProfile.webProperties;
			}

		},
	} );

	Vue.http.options.emulateJSON = true;

	// On document load, check to see if monster insights is being used
	function usingMonsterInsights() {
		Vue.http.post( ajaxurl,
			{
				action: 'adsanity_gati_using_monster_insights',
			}
		).then( function( response ) {
			var usingMonster = response.body.data.usingMonster;
			app.monsterInsights = usingMonster;
			app.askAlreadyTracking = ! usingMonster;
			app.alreadyTracking = usingMonster;
		}, function( err ) {
			app.error = true;
		} );
	}

	usingMonsterInsights();
 })();
