<?php

/**
 * The reports page dashboard
 */

$access_token = adsanity_gati_get_access_token();

if ( ! $access_token ) :
	$configuration_message = sprintf( '<h2>%s</h2><p>%s <a href="%s">%s</a> %s.</p>',
		esc_html__( 'Warning!', 'adsanity-gati' ),
		esc_html__( 'Please configure' ),
		admin_url() . 'edit.php?post_type=ads&page=adsanity-settings&tab=add-ons&sub=google-analytics-tracking-integration',
		esc_html__( 'AdSanity - Google Analytics Tracking Integration', 'adsanity-gati' ),
		esc_html__( 'to view charts and reports', 'adsanity-gati' )
	);
	$configuration_message = apply_filters( 'adsanity_gati_configuration_message', $configuration_message );
	echo $configuration_message;
else :

	$profile_id = 'ga:' . get_option( $this->plugin_name . '-profile_id' );

	$filters = apply_filters( 'adsanity_gati_reports_dashboard_filters', 'ga:eventCategory==AdSanity' );

	$args = array(
		'method' 	=> 'GET',
		'body' 		=> array(
			'start-date' 	=> '2005-01-01',
			'end-date' 		=> 'today',
			'ids' 			=> $profile_id,
			'metrics' 		=> 'ga:totalEvents',
			'dimensions' 	=> 'ga:eventCategory,ga:eventAction,ga:eventLabel',
			'filters' 		=> $filters,
			'access_token' 	=> $access_token,
		),
	);

	$response = wp_remote_get( 'https://www.googleapis.com/analytics/v3/data/ga', $args );

	$total_views = 0;
	$total_clicks = 0;
	$total_ctr = 0;
	$ad_stats = array();

	if ( ! is_wp_error( $response ) && array_key_exists( 'body', $response ) ) {

		$body_json = json_decode( wp_remote_retrieve_body( $response ) );

		if ( property_exists( $body_json, 'rows' ) ) {

			foreach ( $body_json->rows as $row ) {
				// Total stats
				if ( $row[1] == 'view' ) {
					$total_views += $row[3];
				} elseif ( $row[1] == 'click' ) {
					$total_clicks += $row[3];
				}

				// Ad stats
				$ad_stats[ $row[2] ][ $row[1] ] = $row[3];
			}

			$total_ctr = round( $total_clicks / $total_views * 100, 2 );
		}

		// Add ctr to ad_stats
		foreach ( $ad_stats as $key => $val ) {
			if ( array_key_exists( 'click', $val ) ) {
				if ( ! array_key_exists( 'view', $val ) ) {
					$ad_stats[ $key ]['view'] = 0;
					$ad_stats[ $key ]['ctr'] = 0;
				} else {
					$ad_stats[ $key ]['ctr'] = round( $val['click'] / $val['view'] * 100, 2 );
				}
			} else {
				if ( ! array_key_exists( 'view', $val ) ) {
					$ad_stats[ $key ]['view'] = 0;
				}
				$ad_stats[ $key ]['click'] = 0;
				$ad_stats[ $key ]['ctr'] = 0;
			}
		}

	}

?>

<!-- All-Time Summary -->
<div class="all-time-summary">
	<h3><?php _e( 'All-Time Summary', 'adsanity' ) ?></h3>
	<table class="widefat">
	<tbody>
		<tr>
			<td><?php _e( 'Total Views', 'adsanity' ) ?></td>
			<td><?php _e( 'Total Clicks', 'adsanity' ) ?></td>
			<td><?php _e( 'Total Click Through Rate', 'adsanity' ) ?></td>
		</tr>
		<tr>
			<td><?php echo $total_views; ?></td>
			<td><?php echo $total_clicks; ?></td>
			<td><?php echo $total_ctr . '%'; ?></td>
		</tr>
	</tbody>
	</table>
</div>

<!-- COLUMN 1 -->
<div class="all-time-table">
	<h3><?php _e( 'All-Time Top 10 Clicks', 'adsanity' ) ?></h3>
	<table class="widefat">
	<thead>
		<tr>
			<th><?php _e( 'Ad Title', 'adsanity' ) ?></th>
			<th><?php _e( 'Clicks', 'adsanity' ) ?></th>
		</tr>
	</thead>
	<tbody>
		<?php
			uasort( $ad_stats, array( $this, 'sort_by_clicks' ) );
			$sorted_by_clicks = array_slice( $ad_stats, 0, 10 );
			foreach( $sorted_by_clicks as $key => $val ) :
		?>
			<tr>
				<td><?php echo $key ?></td>
				<td><?php echo $val['click']; ?></td>
			</tr>

		<?php endforeach; ?>
	</tbody>
	<tfoot>
		<tr>
			<th><?php _e( 'Ad Title', 'adsanity' ) ?></th>
			<th><?php _e( 'Clicks', 'adsanity' ) ?></th>
		</tr>
	</tfoot>
</table>
</div>

<!-- COLUMN 2 -->
<div class="all-time-table">
	<h3><?php _e( 'All-Time Top 10 Click Through Rate', 'adsanity' ) ?></h3>
	<table class="widefat">
	<thead>
		<tr>
			<th><?php _e( 'Ad Title', 'adsanity' ) ?></th>
			<th><?php _e( 'Views', 'adsanity' ) ?></th>
			<th><?php _e( 'Clicks', 'adsanity' ) ?></th>
			<th><?php _e( 'CTR', 'adsanity' ) ?></th>
		</tr>
	</thead>
	<tbody>
		<?php
			uasort( $ad_stats, array( $this, 'sort_by_ctr' ) );
			$sorted_by_ctr = array_slice( $ad_stats, 0, 10 );
			foreach( $sorted_by_ctr as $key => $val ) :
		?>
			<tr>
				<td><?php echo $key; ?></td>
				<td><?php echo $val['view']; ?></td>
				<td><?php echo $val['click']; ?></td>
				<td><?php echo $val['ctr'] . '%'; ?></td>
			</tr>
		<?php
			endforeach;
		?>
	</tbody>
	<tfoot>
		<tr>
			<th><?php _e( 'Ad Title', 'adsanity' ) ?></th>
			<th><?php _e( 'Views', 'adsanity' ) ?></th>
			<th><?php _e( 'Clicks', 'adsanity' ) ?></th>
			<th><?php _e( 'CTR', 'adsanity' ) ?></th>
		</tr>
	</tfoot>
	</table>
</div>

<!-- Ad Group Block -->
<?php require_once plugin_dir_path( __FILE__ ) . 'reports-page-dashboard-group-block.php'; ?>

<?php endif; ?>
