<?php

/**
 * Adds the script for single ad Google Analytics chart embed
 */

$access_token = adsanity_gati_get_access_token();

if ( ! $access_token ) :
	printf(
		'<p><strong>%s</strong></p><p>%s <a href="%s">%s</a> %s.</p>',
		esc_html__( 'Warning!', 'adsanity-gati' ),
		esc_html__( 'Please configure' ),
		esc_url(
			add_query_arg(
				array(
					'post_type' => 'ads',
					'page'      => 'adsanity-settings',
					'tab'       => 'add-ons',
					'sub'       => 'google-analytics-tracking-integration',
				),
				admin_url( 'edit.php' )
			)
		),
		esc_html__( 'AdSanity - Google Analytics Tracking Integration', 'adsanity-gati' ),
		esc_html__( 'to view charts and reports', 'adsanity-gati' )
	);
else :

	$profile_id = 'ga:' . get_option( $this->plugin_name . '-profile_id' );

	global $post;

	$post_title = adsanity_gati_esc_title( $post->post_title );

	// Retrieves the total events for this ad
	$args = array(
		'method' => 'GET',
		'body'   => array(
			'start-date'   => '2005-01-01',
			'end-date'     => 'today',
			'ids'          => $profile_id,
			'metrics'      => 'ga:totalEvents',
			'dimensions'   => 'ga:eventCategory,ga:eventAction,ga:eventLabel',
			'filters'      => 'ga:eventCategory==AdSanity;ga:eventLabel==' . $post_title,
			'access_token' => $access_token,
		),
	);

	$response = wp_remote_get( 'https://www.googleapis.com/analytics/v3/data/ga', $args );

	if ( ! is_wp_error( $response ) && array_key_exists( 'body', $response ) ) {

		$body_json = json_decode( wp_remote_retrieve_body( $response ) );

		if ( ! property_exists( $body_json, 'rows' ) ) {
			$clicks = 0;
			$views = 0;
			$ctr = 0;
		} else {

			if ( count( $body_json->rows ) > 1 ) {
				$clicks = $body_json->rows[0][3];
				$views = $body_json->rows[1][3];
				$ctr = round( $clicks / $views * 100, 2 );
			} else {
				$views = $body_json->rows[0][3];
				$clicks = 0;
				$ctr = 0;
			}
		}
	} else {
		$clicks = 0;
		$views = 0;
		$ctr = 0;
	}


	// Retrieves the events in the last 7 days for this ad
	$args = array(
		'method' => 'GET',
		'body'   => array(
			'start-date'   => '7daysAgo',
			'end-date'     => 'today',
			'ids'          => $profile_id,
			'metrics'      => 'ga:totalEvents,ga:uniqueEvents',
			'dimensions'   => 'ga:eventCategory,ga:eventAction,ga:eventLabel',
			'filters'      => 'ga:eventCategory==AdSanity;ga:eventLabel==' . $post_title,
			'access_token' => $access_token,
		),
	);

	$response = wp_remote_get( 'https://www.googleapis.com/analytics/v3/data/ga', $args );

	$total_views_last_seven = 0;
	$unique_views_last_seven = 0;
	$total_clicks_last_seven = 0;
	$unique_clicks_last_seven = 0;

	if ( ! is_wp_error( $response ) && array_key_exists( 'body', $response ) ) {

		$body_json = json_decode( wp_remote_retrieve_body( $response ) );

		if ( property_exists( $body_json, 'rows' ) ) {

			foreach ( $body_json->rows as $row ) {

				if ( 'click' === $row[1] ) {
					$total_clicks_last_seven = intval( $row[3] );
					$unique_clicks_last_seven = intval( $row[4] );
				}

				if ( 'view' === $row[1] ) {
					$total_views_last_seven = intval( $row[3] );
					$unique_views_last_seven = intval( $row[4] );
				}

			}

		}

	}

	?>

<h4>Stats Summary</h4>
	<?php
		// Summary.
		echo '<ul class="subsubsub" style="float: none;">';

		// View Count.
		echo sprintf(
			'<li>%s %s |&nbsp;</li>',
			esc_html( number_format_i18n( $views ) ),
			esc_html__( 'Total Views', 'adsanity-gati' )
		);

		// Click Count.
		echo sprintf(
			'<li>%s %s |&nbsp;</li>',
			esc_html( number_format_i18n( $clicks ) ),
			esc_html__( 'Total Clicks', 'adsanity-gati' )
		);

		// Click Through Rate.
		echo sprintf(
			'<li>%s%% %s</li>',
			esc_html( number_format_i18n( $ctr, 2 ) ),
			esc_html__( 'Total CTR', 'adsanity-gati' )
		);

		echo '</ul>';
	?>

<script>
(function(w,d,s,g,js,fs){
	g=w.gapi||(w.gapi={});g.analytics={q:[],ready:function(f){this.q.push(f);}};
	js=d.createElement(s);fs=d.getElementsByTagName(s)[0];
	js.src='https://apis.google.com/js/platform.js';
	fs.parentNode.insertBefore(js,fs);js.onload=function(){g.load('analytics');};
}(window,document,'script'));
</script>

<h4><?php
	printf(
		esc_html__( '%d Total Views in the past 7 days', 'adsanity-gati' ),
		intval( $total_views_last_seven )
	);
	echo ' &nbsp; <span>|</span> &nbsp; ';
	printf(
		esc_html__( '%d Unique Views in the past 7 days', 'adsanity-gati' ),
		intval( $unique_views_last_seven )
	);
?></h4>
<div id="chart-1-container"></div>
<h4><?php
	printf(
		esc_html__( '%d Total Clicks in the past 7 days', 'adsanity-gati' ),
		intval( $total_clicks_last_seven )
	);
	echo ' &nbsp; <span>|</span> &nbsp; ';
	printf(
		esc_html__( '%d Unique Clicks in the past 7 days', 'adsanity-gati' ),
		intval( $unique_clicks_last_seven )
	);
?></h4>
<div id="chart-2-container"></div>

<p><em><?php
	printf(
		wp_kses_post(
			__( 'Statistics and reports pulled from %s can be delayed 24-48 hours. Learn more <a href="%s" target="_blank">here.</a>', 'adsanity-gati' )
		),
		'Google Analytics',
		'https://support.google.com/analytics/answer/1070983?hl=en'
	);
?></em></p>

<script>
gapi.analytics.ready( function() {

	gapi.analytics.auth.authorize( {
		'serverAuth' : {
			'access_token' : '<?php echo $access_token; ?>'
		},
	} );

	var dataChart1 = new gapi.analytics.googleCharts.DataChart( {
		query : {
			'ids' : '<?php echo $profile_id; ?>',
			'start-date' : '7daysAgo',
			'end-date' : 'today',
			'metrics' : 'ga:uniqueEvents,ga:totalEvents',
			'dimensions' : 'ga:date',
			'filters' : 'ga:eventCategory==AdSanity;ga:eventAction==view;ga:eventLabel==<?php echo $post_title; ?>',
		},
		chart : {
			'container' : 'chart-1-container',
			'type' : 'LINE',
			'options' : {
				'width' : '100%',
			},
		},
	} );

	dataChart1.execute();

	dataChart1.on( 'success', function( result ) {
		console.log( result );
	} );

	var dataChart2 = new gapi.analytics.googleCharts.DataChart( {
		query : {
			'ids' : '<?php echo $profile_id; ?>',
			'start-date' : '7daysAgo',
			'end-date' : 'today',
			'metrics' : 'ga:uniqueEvents,ga:totalEvents',
			'dimensions' : 'ga:date',
			'filters' : 'ga:eventCategory==AdSanity;ga:eventAction==click;ga:eventLabel==<?php echo $post_title; ?>',
		},
		chart : {
			'container' : 'chart-2-container',
			'type' : 'LINE',
			'options' : {
				'width' : '100%',
			},
		},
	} );

	dataChart2.execute();

} );
</script>

<?php endif; ?>
