<?php

/**
 * Include the helpers file
 */
require_once plugin_dir_path( __FILE__ ) . 'adsanity-gati-helpers.php';

/**
 * The core plugin class
 */
class Adsanity_GATI {

	/**
	 * The loader responsible for maintaining and registering all hooks that power the plugin
	 */
	protected $loader;

	/**
	 * Unique identifier
	 */
	protected $plugin_name;

	/**
	 * The version for this plugin
	 */
	protected $version;

	/**
	 * The core functionality
	 */
	public function __construct() {

		$this->plugin_name = 'adsanity_gati';
		$this->version = '1.4.1';

		$this->load_dependencies();
		$this->define_admin_hooks();
		$this->define_public_hooks();
		$this->define_admin_ajax_hooks();

	}

	/**
	 * Load the depencies for this plugin
	 */
	private function load_dependencies() {

		/**
		 * Class responsible for orchestrating the actions and filters of the core plugin
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-adsanity-gati-loader.php';

		/**
		 * Class responsible for defining internationalization functionality
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-adsanity-gati-i18n.php';

		/**
		 * Class responsible for defining all actions that occur in the public-facing side
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'public/class-adsanity-gati-public.php';

		/**
		 * Class responsible for defining actions for the admin area
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/class-adsanity-gati-admin.php';

		/**
		 * Class responsible for handling admin ajax requests
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/class-adsanity-gati-admin-ajax.php';

		/**
		 * Class responsible for handling oAuth2 authentication
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/class-adsanity-gati-admin-oauth.php';

		/**
		 * Update engine
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'update-engine/remote-api.php';

		$this->loader = new Adsanity_GATI_Loader();
	}

	/**
	 * Define the locale for this plugin for internationalization.
	 */
	private function set_locale() {

		$plugin_i18n = new Adsanity_GATI_i18n();
		$this->loader->add_action( 'plugins_loaded', $plugin_i18n, 'load_plugin_textdomain' );

	}

	/**
	 * Register hooks related to the admin-area
	 *
	 * Adsanity_Adblock_Detection_Loader - Orchestrates the hooks of the plugin
	 */
	private function define_admin_hooks() {

		$plugin_admin = new Adsanity_GATI_Admin( $this->get_plugin_name(), $this->get_version() );

		$this->loader->add_action( 'admin_init', $plugin_admin, 'register_settings' );
		$this->loader->add_action( 'admin_init', $plugin_admin, 'register_sections' );
		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_script' );
		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_style' );
		$this->loader->add_action( 'add_meta_boxes', $plugin_admin, 'single_ad_charts' );
		$this->loader->add_action( 'add_meta_boxes_ads', $plugin_admin, 'remove_single_ad_stats', 100 );
		$this->loader->add_action( 'admin_menu', $plugin_admin, 'remove_ad_reports', 100 );
		$this->loader->add_action( 'admin_menu', $plugin_admin, 'ad_reports_page' );
		$this->loader->add_filter( 'manage_ads_posts_columns', $plugin_admin, 'todays_stats_columns', 100 );
		$this->loader->add_filter( 'adsanity_ads_posts_columns_adsanity-stats_value', $plugin_admin, 'stats_column_value', 20, 3 );
		$this->loader->add_filter( 'adsanity-addons', $plugin_admin, 'add_settings_tab' );
		$this->loader->add_action( 'admin_init', $plugin_admin, 'settings_section' );
		$this->loader->add_action( 'admin_notices', $plugin_admin, 'configuration_admin_notice' );
		$this->loader->add_action( 'admin_notices', $plugin_admin, 'monster_insights_activated_notice' );
		$this->loader->add_action( 'admin_notices', $plugin_admin, 'monster_insights_deactivated_notice' );
		$this->loader->add_action( 'adsanity_changelog_screen', $plugin_admin, 'changelog' );

	}

	/**
	 * Register public-facing hooks
	 */
	private function define_public_hooks() {

		/**
		 * Create new instance of public class for the plugin
		 */
		$plugin_public = new Adsanity_GATI_Public( $this->get_plugin_name(), $this->get_version() );

		$this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_scripts' );
		$this->loader->add_action( 'adsanity_before_ad', $plugin_public, 'div_before_ad' );
		$this->loader->add_action( 'adsanity_after_ad', $plugin_public, 'close_div' );
		$this->loader->add_action( 'wp_head', $plugin_public, 'google_analytics_script' );

	}

	/**
	 * Register admin ajax hooks
	 */
	private function define_admin_ajax_hooks() {

		$plugin_admin_ajax = new Adsanity_GATI_Admin_Ajax( $this->get_plugin_name(), $this->get_version() );

		$ajax_prefix = 'wp_ajax_' . $this->plugin_name . '_';

		$this->loader->add_action( $ajax_prefix . 'authorization', $plugin_admin_ajax, 'authenticate_code' );
		$this->loader->add_action( $ajax_prefix . 'get_profiles', $plugin_admin_ajax, 'get_profiles' );
		$this->loader->add_action( $ajax_prefix . 'remove_authentication', $plugin_admin_ajax, 'remove_authentication' );
		$this->loader->add_action( $ajax_prefix . 'set_profile', $plugin_admin_ajax, 'set_profile' );
		$this->loader->add_action( $ajax_prefix . 'custom_reports', $plugin_admin_ajax, 'custom_reports' );
		$this->loader->add_action( $ajax_prefix . 'using_monster_insights', $plugin_admin_ajax, 'using_monster_insights' );
		$this->loader->add_action( $ajax_prefix . 'already_tracking', $plugin_admin_ajax, 'using_google_analytics' );
		$this->loader->add_action( $ajax_prefix . 'manual_tracking', $plugin_admin_ajax, 'manual_tracking_id' );
		$this->loader->add_action( $ajax_prefix . 'dismiss_expectation', $plugin_admin_ajax, 'dismiss_expectation' );
		$this->loader->add_action( $ajax_prefix . 'get_ads_by_term', $plugin_admin_ajax, 'get_ads_by_term' );

	}

	/**
	 * Run the loader to execute all hooks
	 */
	public function run() {

		return $this->loader->run();

	}

	/**
	 * Retrieve the plugin name
	 */
	public function get_plugin_name() {

		return $this->plugin_name;

	}

	/**
	 * Reference to the class that orchestrates the hooks
	 */
	public function get_loader() {

		return $this->loader;

	}

	/**
	 * Retrieve the version number
	 */
	public function get_version() {

		return $this->version;

	}
}
