<?php

/**
 * Public facing functionality
 */
class Adsanity_GATI_Public {

	/**
	 * Unique identifier
	 */
	private $plugin_name;

	/**
	 * The version for this plugin
	 */
	private $version;

	/**
	 * The UA code for this plugin
	 */
	private $ua_code;

	/**
	 * Initialize the class and set its properties.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;
		$this->ua_code = $this->get_ua_code();

	}

	/**
	 * Get the UA Code
	 */
	private function get_ua_code() {

		$ua_code = (string) get_option( $this->plugin_name . '-tracking_id' );
		$ua_code = trim( $ua_code );

		// Return if the tracking ID isn't set
		if ( empty( $ua_code ) ) {
			return false;
		}

		// Replace all type of dashes (n-dash, m-dash, minus) with normal dashes.
		$ua_code = str_replace( array( '–', '—', '−' ), '-', $ua_code );

		// return if the UA code isn't valid
		if ( ! preg_match( "/^(UA|YT|MO)-\d{4,}-\d+$/", strval( $ua_code ) ) ) {
			return false;
		}

		return $ua_code;

	}

	/**
	 * Enqueue our public facing scripts
	 */
	public function enqueue_scripts() {

		$adsanity_options = get_option( 'adsanity-options', false );

		// Return if we are not tracking this user type
		if ( $adsanity_options && is_array( $adsanity_options ) && ! empty( $adsanity_options['adsanity_ignore_roles'] ) ) {
			$roles = $adsanity_options['adsanity_ignore_roles'];
			if ( is_array( $roles ) ) {
				// For each role check if user can
				foreach( $roles as $role ) {
					if ( current_user_can( $role ) ) {
						return;
					}
				}
			} else {
				// Rare case of a single excluded role getting cast to a string
				if ( current_user_can( $roles ) ) {
					return;
				}
			}
		}

		wp_enqueue_script(
			$this->plugin_name,
			plugin_dir_url( __FILE__ ) . 'js/adsanity-gati-public.js',
			array(),
			$this->version,
			true
		);

		// Localize ua code for use in script insertion
		if ( ! $this->ua_code ) {
			return;
		}

		$using_google = get_option( $this->plugin_name . '-already_tracking' );
		if ( 'true' === $using_google ) {
			$track_pageviews = '0';
		} else {
			$track_pageviews = '1';
		}

		wp_localize_script(
			$this->plugin_name,
			'ADSANITY_GATI',
			array(
				'ua_code' => $this->ua_code,
				'track_pageviews' => $track_pageviews,
			)
		);

	}

	/**
	 * Add google analytics script to head
	 */
	public function google_analytics_script() {

		if ( function_exists( 'MonsterInsights' ) ) {
			return;
		}

		// Return if using another GA integration
		$using_google = get_option( $this->plugin_name . '-already_tracking' );
		if ( 'true' === $using_google ) {
			return;
		}

		if ( ! $this->ua_code ) {
			return;
		}

		$adsanity_options = get_option( 'adsanity-options', false );

		// Return if we are not tracking this user type
		if ( $adsanity_options && is_array( $adsanity_options ) && ! empty( $adsanity_options['adsanity_ignore_roles'] ) ) {
			$roles = $adsanity_options['adsanity_ignore_roles'];
			if ( is_array( $roles ) ) {
				// For each role check if user can
				foreach( $roles as $role ) {
					if ( current_user_can( $role ) ) {
						return;
					}
				}
			} else {
				// Rare case of a single excluded role getting cast to a string
				if ( current_user_can( $roles ) ) {
					return;
				}
			}
		}

		echo "<!-- Google Analytics -->
			<script>
			(function(i,s,o,g,r,a,m){i['GoogleAnalyticsObject']=r;i[r]=i[r]||function(){
			(i[r].q=i[r].q||[]).push(arguments)},i[r].l=1*new Date();a=s.createElement(o),
			m=s.getElementsByTagName(o)[0];a.async=1;a.src=g;m.parentNode.insertBefore(a,m)
			})(window,document,'script','https://www.google-analytics.com/analytics.js','ga');
			ga('create', '" . $this->ua_code . "', 'auto');
			ga('send', 'pageview');
			</script>
			<!-- End Google Analytics -->";

	}

	/**
	 * Add a div before each ad
	 */
	public function div_before_ad() {

		global $post;

		$title = adsanity_gati_esc_title( $post->post_title );

		echo '<div class="adsanity-gati" data-title="' . $title . '">';

	}

	/**
	 * Close div after each ad
	 */
	public function close_div() {

		echo '</div>';

	}

}
