<?php

/**
 * Admin plugin functionality
 */
class Adsanity_OAGW_Admin {

	/**
	 * Unique identifier
	 */
	private $plugin_name;

	/**
	 * The version for this plugin
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 */
	public function __construct( $plugin_name, $version ) {
		$this->plugin_name = $plugin_name;
		$this->version = $version;
	}

	/**
	 * Register TinyMCE button for use
	 */
	public function register_tinymce_button( $buttons = array() ) {

		array_push( $buttons, 'adsanity_oagw' );
		return $buttons;

	}

	/**
	 * Add button to TinyMCE
	 */
	public function add_tinymce_plugin( $plugins = array() ) {

		global $post;

		if ( isset( $post->post_type ) && 'ads' === $post->post_type ) {
			return $plugins;
		}

		// Ensure that the proper WordPress Core dependencies are enqueued
		wp_enqueue_script( 'wp-api-fetch' );
		wp_enqueue_script( 'wp-i18n' );
		wp_enqueue_script( 'wp-url' );
		wp_enqueue_script( 'underscore' );
		wp_enqueue_script( 'react-dom' );

		$plugins[ 'AdSanityOrderedAdGroupWidget' ] = plugin_dir_url( __FILE__ ) . 'dist/js/tinymce.js';
		return $plugins;

	}

	/**
	 * Set up translations and data for tinymce
	 *
	 * @return void
	 */
	public function tinymce_javascript_object() {

		global $current_screen;

		if ( is_admin() ) {
			?>
			<script type="text/javascript">
				var AdSanityOAGWMCE = {
					adsanity_oagw_title: '<?php _e( 'Insert Order Ad Group', 'adsanity-oagw' ); ?>',
				};
			</script>
			<?php
		}
	}

	/**
	 * Ajax hook for shortcode modal window
	 */
	public function adsanity_oagw_shortcode_form() {

		$ads = adsanity_ads_select_list();
		require( plugin_dir_path( __FILE__ ) . 'lib/oagw-popup.php' );
		wp_die();

	}

	/**
	 * Enqueue the scripts for admin
	 */
	public function enqueue_script( $hook ) {

		global $current_screen;

		if ( $hook == 'widgets.php' ) {
			wp_enqueue_script(
				$this->plugin_name . '-widget',
				plugin_dir_url( __FILE__ ) . 'dist/js/adsanity-oagw-widget.js',
				array( 'jquery', 'wp-api-fetch', 'wp-i18n', 'wp-url', 'underscore', 'react-dom', ),
				$this->version
			);
		}

	}

	/**
	 * Enqueue styles for admin
	 */
	public function enqueue_style( $hook ) {

		global $current_screen;

		if ( $hook == 'widgets.php' ) {
			wp_enqueue_style(
				$this->plugin_name,
				plugin_dir_url( __FILE__ ) . 'dist/css/adsanity-oagw-widget.css',
				array(),
				$this->version
			);
		}

		if ( is_admin() && 'post' == $current_screen->base ) {
			wp_enqueue_style(
				$this->plugin_name . '-tinymce',
				plugin_dir_url( __FILE__ ) . 'dist/css/adsanity-oagw-tinymce.css',
				array(),
				$this->version
			);
		}

	}

	/**
	 * Reference to the widget class
	 */
	public function add_widget() {

		require_once( plugin_dir_path( __FILE__ ) . 'class-adsanity-oagw-widget.php' );
		register_widget( 'Adsanity_OAGW_Widget' );

	}

	/**
	 * Enqueue Gutenberg scripts
	 */
	public function gutenberg_scripts() {

		wp_enqueue_script(
			$this->plugin_name . '-block',
			plugin_dir_url( __FILE__ ) . 'dist/js/block.js',
			array( 'wp-blocks', 'wp-i18n', 'wp-url', 'wp-api-fetch', 'wp-element', 'wp-components', ),
			$this->version
		);

		wp_enqueue_style(
			$this->plugin_name . '-block',
			plugin_dir_url( __FILE__ ) . 'dist/css/block.css',
			array(),
			$this->version
		);

	}

	/**
	 * Register block type for rotating ads
	 */
	public function register_block_type() {

		if ( ! function_exists( 'register_block_type' ) ) {
			return;
		}

		register_block_type( 'adsanity/ordered-ads', array(
			'attributes' => array(
				'is_gutenberg' => array(
					'type'    => 'boolean',
					'default' => true,
				),
				'ads' => array(
					'type' => 'array',
				),
				'num_columns' => array(
					'type'    => 'number',
					'default' => 1,
				),
				'align' => array(
					'type' => 'string',
					'default' => 'alignnone',
				),
				'max_width' => array(
					'type' => 'number',
					'default' => 0,
				),
				// Send attribute of return => true so that the ad is not printed
				'return' => array(
					'type'    => 'boolean',
					'default' => true,
				),
			),
			'render_callback' => 'adsanity_show_ordered_ads',
		) );

	}

	public function changelog() {
		require_once plugin_dir_path( __FILE__ ) . 'partials/changelog.php';
	}

}
