<?php

/**
 * Widget for Ordered Ads
 */
class Adsanity_OAGW_Widget extends WP_Widget {

	/**
	 * Default number of columns.
	 *
	 * @var $num_columns
	 */
	var $num_columns = 1;

	/**
	 * Sets up the widgets name
	 */
	public function __construct() {

		$widget_ops = array(
			'classname'                   => 'widget adsanity-group adsanity-oagw',
			'description'                 => __( 'Display an Ordered Ad Group', 'adsanity-oagw' ),
			'customize_selective_refresh' => true,
		);

		parent::__construct( 'adsanity-oagw', __( 'Adsanity - Ordered Ad Group', 'adsanity-oagw' ), $widget_ops );

	}

	/**
	 * Outputs the markup for this widget
	 */
	public function widget( $args, $instance ) {

		if ( ! isset( $instance['title'] ) ) {
			$instance['title'] = '';
		}

		if ( ! isset( $instance['ad_ids'] ) ) {
			$instance['ad_ids'] = array();
		}

		extract( $args, EXTR_SKIP );

		$widget_args = array(
			'is_widget'   => 'true',
			'title'       => $instance[ 'title' ],
			'widget_args' => $args,
			'ad_ids'      => $instance[ 'ad_ids' ],
			'num_columns' => $instance[ 'num_columns' ],
			'ad_ids'      => $instance[ 'ad_ids' ],
			'max_width'   => $instance[ 'max_width' ],
			'align'       => $instance[ 'align' ],
		);

		if ( array_key_exists( 'num_columns', $instance ) ) {
			$widget_args['num_columns'] = $instance['num_columns'];
		}

		if ( array_key_exists( 'align', $instance ) ) {
			$widget_args['align'] = $instance['align'];
		}

		if ( array_key_exists( 'max-width', $instance ) && $instance['max-width'] ) {
			$widget_args['max_width'] = $instance['max-width'];
		}

		adsanity_show_ordered_ads( $widget_args );

	}

	/**
	 * Outputs the options form on admin
	 */
	public function form( $instance ) {

		$defaults = array(
			'title'       => '',
			'num_columns' => $this->num_columns,
			'ad_ids'      => array(),
			'align'       => 'alignnone',
			'max_width'   => false,
		);

		$instance = wp_parse_args( $instance, $defaults );

		printf(
			'<p><label for="%s">%s</label>',
			$this->get_field_id( 'title' ),
			__( 'Title:', 'adsanity-oagw' )
		);
		printf(
			'<input class="widefat" id="%s" name="%s" type="text" value="%s" /></p>',
			$this->get_field_id( 'title' ),
			$this->get_field_name( 'title' ),
			esc_attr( $instance[ 'title' ] )
		);

		// Trigger an event to initialize the React app
		echo '<script>
			window.jQuery( document ).trigger("adsanity-oagw-widget-init");
		</script>';

		// Container for the React app
		echo '<div class="adsanity-oagw-widget-app"></div>';

		// Print the ads
		$raw_ads = $instance['ad_ids'];
		$ads = array();

		if ( is_array( $raw_ads ) && ! empty( $raw_ads ) ) {

			foreach ( $raw_ads as $raw_ad ) {
				$ads[] = array(
					'value' => $raw_ad,
					'label' => get_the_title( $raw_ad ),
				);
			}

		}

		// This element passes data to the React app for this widget instance
		printf(
			'<div
				class="adsanity-oagw-widget-data"
				data-field-name-ads="%s"
				data-field-name-columns="%s"
				data-field-name-align="%s"
				data-field-name-max-width="%s"
				data-field-value-ads="%s"
				data-field-value-columns="%s"
				data-field-value-align="%s"
				data-field-value-max-width="%s"
			></div>',
			esc_attr( $this->get_field_name( 'ad_ids' ) ),
			esc_attr( $this->get_field_name( 'num_columns' ) ),
			esc_attr( $this->get_field_name( 'align' ) ),
			esc_attr( $this->get_field_name( 'max_width' ) ),
			esc_attr( wp_json_encode( $ads ) ),
			esc_attr( $instance[ 'num_columns' ] ),
			esc_attr( $instance[ 'align' ] ),
			esc_attr( $instance[ 'max_width' ] )
		);

	}

	/**
	 * Processing widget options on save
	 */
	function update( $new_instance, $old_instance ) {

		$updated_instance = $new_instance;

		if ( ! is_array( $updated_instance['ad_ids'] ) ) {
			$updated_instance['ad_ids'] = explode( ',', $updated_instance['ad_ids'] );
		}

		return $updated_instance;
	}
}
