import { Component, }       from 'react';
import AsyncSelect          from 'react-select/async';
import { AllHtmlEntities, } from 'html-entities';
import arrayMove            from 'array-move';

const $                 = window.jQuery;
const apiFetch          = window.wp.apiFetch;
const { addQueryArgs, } = window.wp.url;
const { __, }           = window.wp.i18n;
const _                 = window._;

// Local imports
import iconAlignCenter from './svg/align-center';
import iconAlignLeft   from './svg/align-left';
import iconAlignRight  from './svg/align-right';
import iconArrowDown   from './svg/arrow-down';
import iconArrowUp     from './svg/arrow-up';
import iconClose       from './svg/close';

// Imports from AdSanity core
import selectTheme from '../../../../adsanity/src/js/blocks/common/select-theme';

// This will allow us to decode HTML entities
const entities = new AllHtmlEntities();

class App extends Component {

	constructor( props ) {
		super( props );
		this.state = {
			value             : '',
			ads               : [],
			columns           : 1,
			align             : 'alignnone',
			maxWidthEnabled   : false,
			maxWidth          : 100,
			fieldNameAds      : '',
			fieldNameColumns  : '',
			fieldNameAlign    : '',
			fieldNameMaxWidth : '',
		};
		this.eventListeners = this.eventListeners.bind( this );
		this.eventListeners();

	}

	// After this component mounts, use ref to see if there is data for state
	componentDidMount() {

		const data = $( this._element )
			.closest( '.adsanity-oagw-widget-app' )
			.next( '.adsanity-oagw-widget-data' );

		if ( ! data.length ) {
			return;
		}

		const maxWidth = data.data( 'field-value-max-width' );

		this.setState( {
			ads               : data.data( 'field-value-ads' ),
			columns           : data.data( 'field-value-columns' ),
			align             : data.data( 'field-value-align' ),
			maxWidthEnabled   : maxWidth ? true : false,
			maxWidth          : maxWidth ? maxWidth : this.state.maxWidth,
			fieldNameAds      : data.data( 'field-name-ads' ),
			fieldNameColumns  : data.data( 'field-name-columns' ),
			fieldNameAlign    : data.data( 'field-name-align' ),
			fieldNameMaxWidth : data.data( 'field-name-max-width' ),
		} );

	}

	eventListeners() {

		$( document ).on( 'adsanity-oagw-submit-tinymce', () => {

			const adIds = this.state.ads.map( ( ad ) => {
				return ad.value;
			} ).join( ',' );
			
			let shortcode = `[adsanity_ordered ad_ids="${ adIds }" num_columns="${ this.state.columns }" align="${ this.state.align }"`;

			if ( this.state.maxWidthEnabled ) {
				shortcode += ` max_width="${ this.state.maxWidth }"`;
			}

			shortcode += '/]';
			
			window.adsanityOAGWTinyMCEShortcode = shortcode;
		} )

	}

	render() {

		//
		// Load ads for the select component
		//
		const loadOptions = ( value, callback ) => {

			let args = {
				per_page : 100,
			};

			if ( value ) {
				args.orderby = 'relevance';
				args.search  = value;
			}

			apiFetch( {
				path: addQueryArgs( '/wp/v2/ads/', args ),
			} )
			.then( ( posts ) => {
				posts = posts.map( ( post ) => {
					return {
						value: post.id,
						label: entities.decode( post.title.rendered ),
					};
				} );
				callback( posts );
			} )
			.catch( ( error ) => {
				console.log( error );
			} );

		}

		// Handle a change to the ad select
		const handleAdChange = ( value ) => {

			this.setState( {
				value             : '',
				ads               : this.state.ads.concat( [ value ] ),
				currentDropTarget : null,
			} );

			$( this._adsHidden ).trigger( 'change' );

		}

		const handleDragStart = ( event ) => {

			event.target.style.opacity = '0.8';
			event.dataTransfer.effectAllowed = 'move';
			event.dataTransfer.setData( 'text/html', event.target.innerHTML );

			this.setState( {
				currentDropTarget: event.target,
			} );

		}

		const handleDragOver = ( event ) => {

			if ( event.preventDefault ) {
				event.preventDefault();
			}

			event.dataTransfer.dropEffect = 'move';

			return;

		}

		const handleDragEnter = ( event ) => {

			event.target.classList.add( 'over' );

		}

		const handleDragLeave = ( event ) => {

			event.target.classList.remove( 'over' );

		}

		const handleDrop = ( event ) => {

			if ( event.stopPropagation ) {
				event.stopPropagation();
			}

			const moveFrom = Number.parseInt( this.state.currentDropTarget.attributes['data-index'].value );
			const moveTo = Number.parseInt( event.target.attributes['data-index'].value );

			if ( moveFrom === moveTo ) {
				return;
			}

			moveAd( moveFrom, moveTo );

		}

		const handleDragEnd = ( event ) => {

			event.target.style.opacity = '1';
			event.target.classList.remove( 'over' );

			document.querySelectorAll( '#adsanity-oagw-shortcode-app .ad, .adsanity-oagw-widget-app .ad' ).forEach( function( ad ) {
				ad.classList.remove( 'over' );
			} );

		}

		const adList = this.state.ads.map( ( ad, index ) => {
			return (
					<div
						className="ad"
						key={ index }
						data-index={ index }
						draggable="true"
						onDragStart={ handleDragStart }
						onDragOver={ handleDragOver }
						onDragEnter={ handleDragEnter }
						onDragLeave={ handleDragLeave }
						onDrop={ handleDrop }
						onDragEnd={ handleDragEnd }
					>
						<p>{ ad.label }</p>

						<div className="buttons">
							<button
								type="button"
								aria-label={ __( 'Move Up', 'adsanity-oagw' ) }
								disabled={ index === 0 }
								onClick={ () => { moveAd( index, index - 1 ); } }
							>
								{ iconArrowUp }
							</button>
							<button
								type="button"
								aria-label={ __( 'Move Down', 'adsanity-oagw' ) }
								disabled={ index === this.state.ads.length - 1 }
								onClick={ () => { moveAd( index, index + 1 ); } }
							>
								{ iconArrowDown }
							</button>
							<button
								type="button"
								aria-label={ __( 'Remove', 'adsanity-oagw' ) }
								disabled={ this.state.ads.length < 2 }
								onClick={ () => { removeAd( index ); } }
							>
								{ iconClose }
							</button>
						</div>
					</div>
			);
		} );

		const moveAd = ( from, to ) => {

			this.setState( {
				ads: arrayMove( this.state.ads, from, to ),
			} );

			$( this._adsHidden ).trigger( 'change' );

		}

		const removeAd = ( index ) => {

			const ads = this.state.ads;
			ads.splice( index, 1 );

			this.setState( {
				ads,
			} );

			$( this._adsHidden ).trigger( 'change' );

		}

		const handleColumnChange = ( event ) => {

			let value = event.target.value.replace( /\D/g, '' );
			if ( value < 1 ) {
				value = '';
			}

			this.setState( {
				columns: value,
			} );

		}

		const handleMaxWidthEnabledChange = ( event ) => {

			this.setState( {
				maxWidthEnabled: ! this.state.maxWidthEnabled,
			} );

		}

		const handleMaxWidthChange = ( event ) => {

			let value = event.target.value.replace( /\D/g, '' );
			if ( value < 1 ) {
				value = '';
			}

			this.setState( {
				maxWidth: value,
			} );

		}

		const handleAlignChange = ( align ) => {

			this.setState( {
				align,
			} );

			$( this._alignHidden ).trigger( 'change' );

		}

		return (
			<div
				ref={ ( element ) => this._element = element }
			>
				<label>
					<p>{ __( 'Select an ad:', 'adsanity-oagw' ) }</p>
					<AsyncSelect
						className="select"
						cacheOptions
						defaultOptions
						loadOptions={ loadOptions }
						theme={ selectTheme }
						onChange={ handleAdChange }
						value={ this.state.value }
					/>
				</label>
				{ adList }

				<hr/>

				<div className="num-columns">
					<label>
						<p>{ __( 'Number of Columns:', 'adsanity-oagw' ) }</p>
						<input
							type="number"
							value={ this.state.columns }
							onChange={ handleColumnChange }
						/>
					</label>
				</div>

				<hr/>

				<div className="align">
					<p>{ __( 'Align:', 'adsanity-oagw' ) }</p>
					<div className="buttons">
						<button
							type="button"
							className={ 'alignleft' === this.state.align ? 'active' : '' }
							onClick={ () => { handleAlignChange( 'alignleft' ) } }
						>
							{ iconAlignLeft }
						</button>
						<button
							type="button"
							className={ 'aligncenter' === this.state.align ? 'active' : '' }
							onClick={ () => { handleAlignChange( 'aligncenter' ) } }
						>
							{ iconAlignCenter }
						</button>
						<button
							type="button"
							className={ 'alignright' === this.state.align ? 'active' : '' }
							onClick={ () => { handleAlignChange( 'alignright' ) } }
						>
							{ iconAlignRight }
						</button>
						<button
							type="button"
							className={ 'alignnone' === this.state.align ? 'active' : '' }
							onClick={ () => { handleAlignChange( 'alignnone' ) } }
						>
							{ iconClose }
						</button>
					</div>
				</div>

				<hr/>

				<div className="max-width">
					<label className="max-width-enabled">
						<input
							type="checkbox"
							value={ this.state.maxWidthEnabled }
							checked={ this.state.maxWidthEnabled ? 'checked': '' }
							onChange={ handleMaxWidthEnabledChange }
						/>
						<p>{ __( 'Max Width Enabled?', 'adsanity-oagw' ) }</p>
					</label>
					<label
						style={ { display: this.state.maxWidthEnabled ? 'block' : 'none', } }
					>
						<p>{ __( 'Max Width (px):', 'adsanity-oagw' ) }</p>
						<input
							type="number"
							value={ this.state.maxWidth }
							onChange={ handleMaxWidthChange }
						/>
					</label>
				</div>

				<div className="hidden-input">
					<input
						type="hidden"
						name={ this.state.fieldNameAds }
						value={ this.state.ads.map( ( ad ) => {
							return ad.value;
						} ) }
						ref={ ( element ) => this._adsHidden = element }
					/>
					<input
						type="hidden"
						name={ this.state.fieldNameColumns }
						value={ this.state.columns }
					/>
					<input
						type="hidden"
						name={ this.state.fieldNameAlign }
						value={ this.state.align }
						ref={ ( element ) => this._alignHidden = element }
					/>
					<input
						type="hidden"
						name={ this.state.fieldNameMaxWidth }
						value={ this.state.maxWidthEnabled ? this.state.maxWidth : '' }
					/>
				</div>

			</div>
		);

	}

}

export default App;
