import { DragDropContext, Draggable, Droppable, } from 'react-beautiful-dnd';
import Ad from './Ad';

function AdList( props ) {

	const { ads, } = props;

	const onAdUp = ( value ) => {
		props.onAdUp( value );
	};

	const onAdDown = ( value ) => {
		props.onAdDown( value );
	};

	const onAdRemove = ( value ) => {
		props.onAdRemove( value );
	};

	const onDragEnd = ( result ) => {
		if ( ! result.source || ! result.destination ) {
			return;
		}
		if ( result.source.index === result.destination.index ) {
			return;
		}
		props.onDragEnd( result.source.index, result.destination.index );
	};

	const adList = ads.map( function( ad, index ) {
		return (
			<Draggable key={ ad.id } draggableId={ new Number( ad.id ).toString() } index={ index }>
				{ ( provided, snapshot ) => (
					<div
						className="ad-container"
						ref={ provided.innerRef }
						{ ...provided.draggableProps }
						{ ...provided.dragHandleProps }
					>
						<Ad
							ad={ ad }
							index={ index }
							onAdUp={ onAdUp }
							onAdDown={ onAdDown }
							onAdRemove={ onAdRemove }
							numAds={ ads.length }
						/>
					</div>
				) }
			</Draggable>
		);
	} );

	return (
		<DragDropContext onDragEnd={ onDragEnd }>
			<Droppable droppableId="droppable">
			{ ( provided, snapshot ) => (
				<div
					ref={ provided.innerRef }
					className="adsanity-ad-list"
					{ ...provided.droppableProps }
				>
					{ adList }
					{ provided.placeholder }
				</div>
			) }
			</Droppable>
		</DragDropContext>
	);

}

export default AdList;
