<?php

/**
 * The core plugin class
 */
class Adsanity_OAGW {

	/**
	 * The loader responsible for maintaining and registering all hooks that power the plugin
	 */
	protected $loader;

	/**
	 * Unique identifier
	 */
	protected $plugin_name;

	/**
	 * The version for this plugin
	 */
	protected $version;

	/**
	 * The core functionality
	 */
	public function __construct() {

		$this->plugin_name = 'adsanity_oagw';
		$this->version = '1.5';

		$this->load_dependencies();
		$this->define_admin_hooks();
		$this->define_public_hooks();
		$this->define_bb_hooks();

	}

	/**
	 * Load the depencies for this plugin
	 */
	private function load_dependencies() {

		/**
		 * Class responsible for orchestrating the actions and filters of the core plugin
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-adsanity-oagw-loader.php';

		/**
		 * Class responsible for defining internationalization functionality
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-adsanity-oagw-i18n.php';

		/**
		 * Class responsible for defining all actions that occur in the public-facing side
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'public/class-adsanity-oagw-public.php';

		/**
		 * Class responsible for defining actions for the admin area
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/class-adsanity-oagw-admin.php';

		/**
		 * Class responsible for Beaver Builder module
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'page-builders/beaver-builder/class-adsanity-oagw-bb.php';

		/**
		 * Class responsible for Divi module
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'page-builders/divi/divi.php';

		/**
		 * Update Engine
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'update-engine/remote-api.php';

		$this->loader = new Adsanity_OAGW_Loader();
	}

	/**
	 * Define the locale for this plugin for internationalization.
	 */
	private function set_locale() {

		$plugin_i18n = new Adsanity_OAGW_i18n();
		$this->loader->add_action( 'plugins_loaded', $plugin_i18n, 'load_plugin_textdomain' );

	}

	/**
	 * Register hooks related to the admin-area
	 *
	 * Adsanity_Rotating_Ads_Loader - Orchestrates the hooks of the plugin
	 */
	private function define_admin_hooks() {

		$plugin_admin = new Adsanity_OAGW_Admin( $this->get_plugin_name(), $this->get_version() );

		$this->loader->add_filter( 'mce_external_plugins', $plugin_admin, 'add_tinymce_plugin', 110 );
		$this->loader->add_filter( 'mce_buttons', $plugin_admin, 'register_tinymce_button', 110 );

		$this->loader->add_action( 'admin_head', $plugin_admin, 'tinymce_javascript_object' );
		$this->loader->add_action( 'wp_ajax_adsanity_oagw_shortcode_form', $plugin_admin, 'adsanity_oagw_shortcode_form' );
		$this->loader->add_action( 'widgets_init', $plugin_admin, 'add_widget' );
		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_script' );
		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_style' );

		$this->loader->add_action( 'enqueue_block_editor_assets', $plugin_admin, 'gutenberg_scripts' );
		$this->loader->add_action( 'init', $plugin_admin, 'register_block_type' );
		$this->loader->add_action( 'adsanity_changelog_screen', $plugin_admin, 'changelog' );

	}

	/**
	 * Register public-facing hooks
	 */
	private function define_public_hooks() {

		/**
		 * Create new instance of public class for the plugin
		 */
		$plugin_public = new Adsanity_OAGW_Public( $this->get_plugin_name(), $this->get_version() );

		$this->loader->add_action( 'init', $plugin_public, 'register_shortcodes' );

	}

	/**
	 * Register Beaver Builder hooks
	 */
	private function define_bb_hooks() {

		/**
		 * Create new instance of BB class for the plugin
		 */
		$plugin_bb = new AdSanity_OAGW_BB();

		$this->loader->add_action( 'init', $plugin_bb, 'load_module' );

	}

	/**
	 * Run the loader to execute all hooks
	 */
	public function run() {

		return $this->loader->run();

	}

	/**
	 * Retrieve the plugin name
	 */
	public function get_plugin_name() {

		return $this->plugin_name;

	}

	/**
	 * Reference to the class that orchestrates the hooks
	 */
	public function get_loader() {

		return $this->loader;

	}

	/**
	 * Retrieve the version number
	 */
	public function get_version() {

		return $this->version;

	}
}
