<?php
/**
 * Ordered Ads template tag
 */
function adsanity_show_ordered_ads( $args = array() ) {

	$defaults = array(
		'is_gutenberg' => false,
		'is_widget'    => false,
		'widget_args'  => array(),
		'title'        => false,
		'num_columns'  => 1,
		'return'       => false,
		'ad_ids'       => array(),
		'ads'          => 0,
		'align'        => 'alignnone',
		'max_width'    => false,
	);
	$values = wp_parse_args( $args, $defaults );
	extract( $values, EXTR_SKIP );

	// Sometimes max width is enabled, but no value is passed
	// for the actual max width. This should default to 100
	if (
		isset( $args['max_width_enabled'] ) &&
		$args['max_width_enabled'] &&
		! $max_width
	) {
		$max_width = 100;
	}

	// Gutenberg needs to loop through an array of objects ($ads) for $ad_ids
	if ( $is_gutenberg && is_array( $ads ) ) {
		foreach ( $ads as $ad ) {
			array_push( $ad_ids, $ad['id'] );
		}
	}

	// Hide ads if needed
	if ( empty( apply_filters( 'adsanity_hide_ad_group', array( '' ) ) ) ) {
		return;
	}

	foreach ( $ad_ids as $key => $ad_id ) {
		if ( apply_filters( 'adsanity_hide_ad', false, $ad_id ) ) {
			array_splice( $ad_ids, $key, 1 );
		}
	}

	// Start object stream if we are returning for shortcode
	if ( isset( $return ) && true == $return ) {
		ob_start();
	}

	if ( isset( $ad_ids ) && count( $ad_ids ) < 1 ) {
		return false;
	}

	$now = time();

	// Get the cached version of the ads first
	$cache_key = sprintf(
		'adsanity-ordered-ad-group-%s',
		AdSanityUtility::hash( serialize( array_merge( $values, $ad_ids ) ) )
	);
	$ads = get_transient( $cache_key );
	if ( false === $ads ) {
		delete_transient( $cache_key );

		$ads = new WP_Query(
			array(
				'post_type'	=> 'ads',
				'post__in' 	=> $ad_ids,
				'orderby'	=> 'post__in',
				'meta_query' => array(
					array(
						'key' => '_start_date',
						'value' => $now,
						'type' => 'numeric',
						'compare' => '<='
					),
					array(
						'key' => '_end_date',
						'value' => $now,
						'type' => 'numeric',
						'compare' => '>='
					)
				),
			)
		);

		// cache for 60 seconds
		set_transient( $cache_key, $ads, DAY_IN_SECONDS );
	}

	if ( $ads->have_posts() ) {

		if ( isset( $is_widget ) && true == $is_widget ) {
			echo $widget_args['before_widget'];

			if ( isset( $title ) && ! empty( $title ) ) {
				echo $widget_args['before_title'];
				echo $title;
				echo $widget_args['after_title'];
			}
		}

		printf( '<div class="ad-%s">', esc_attr( $align ) );

		$index = 0;
		while ( $ads->have_posts() ) {

			$ads->the_post();

			if ( 0 === $index || 0 === $index % $num_columns ) {
				echo '<div class="ad-row">';
			}

			// Count the view
			adsanity_view( get_the_ID() );

			$size = get_post_meta( get_the_ID(), '_size', true );

			// override in a parent or child theme
			$custom_template = locate_template(array(
				sprintf( 'ad-%s.php', get_the_ID() ),
				sprintf( 'ad-%s.php', $size ),
				'ad.php'
			));

			if ( ! empty( $custom_template ) ) {
				require( $custom_template );
			} else {
				require( ADSANITY_THEME . 'ad.php' );
			}

			if ( $ads->post_count === ( $index - 1 ) || ( $index + 1 ) % $num_columns === 0 ) {
				echo '</div>';
			}

			++$index;

		}

		// Close up the ad-row div if necessary.
		if ( 0 !== $index % $num_columns ) {
			echo '</div>';
		}

		// Close up the alignment div.
		echo '</div>';

		if ( isset( $is_widget ) && true == $is_widget ) {
			echo $widget_args['after_widget'];
		}

		wp_reset_postdata();
	}

	if ( isset( $return ) && true == $return ) {
		$output = ob_get_contents();
		ob_end_clean();
		return $output;
	}

}
