const webpack = require( 'webpack' );
const inProduction = process.env.NODE_ENV === 'production';
const WebpackCleanPlugin = require( 'webpack-clean' );
const MiniCssExtractPlugin = require( 'mini-css-extract-plugin' );
const OptimizeCSSAssetsPlugin = require( 'optimize-css-assets-webpack-plugin' );
const path = require( 'path' );
const TerserPlugin = require('terser-webpack-plugin');

const entry = {
	'admin/dist/js/adsanity-oagw-widget'   : './admin/src/js/adsanity-oagw-widget',
	'admin/dist/js/tinymce'                : './admin/src/js/tinymce',
	'admin/dist/js/block'                  : './admin/src/js/block',
	'admin/dist/css/adsanity-oagw-tinymce' : './admin/src/sass/adsanity-oagw-tinymce.scss',
	'admin/dist/css/adsanity-oagw-widget'  : './admin/src/sass/adsanity-oagw-widget.scss',
	'admin/dist/css/block'                 : './admin/src/sass/block.scss',

	// Divi scripts live in their specific folder
	'page-builders/divi/scripts/builder-bundle.min' : './page-builders/divi/includes/loader.js',
}

const plugins = [
	new MiniCssExtractPlugin({
		filename: "[name].css",
	}),
	new WebpackCleanPlugin(
		Object.keys( entry )
			.filter( ( key ) => key.includes( '/css/' ) )
			.map( ( key ) => key + '.js' )
	),
];

if ( inProduction ) {
	plugins.push( new TerserPlugin({}), );
	plugins.push( new webpack.optimize.ModuleConcatenationPlugin() );
	plugins.push( new webpack.NoEmitOnErrorsPlugin() );
}

module.exports = {
	entry,
	output: {
		path: path.resolve( __dirname, './' ),
		filename: '[name].js',
	},
	module: {
		rules: [
			{
				test: /\.js$/,
				use: 'babel-loader',
			},
			{
				test: /\.(png|jpg|svg|eot|ttf|woff)$/,
				use: [
					{
						loader: 'url-loader', options: {
							limit: 10000
						},
					},
				],
			},
			{
				test: /\.(css|scss)$/,
				use: [
					MiniCssExtractPlugin.loader,
					{
						loader: 'css-loader',
					},
					'sass-loader',
				],
			},
		],
		
	},
	plugins,
	optimization: {
		minimizer: [
			new OptimizeCSSAssetsPlugin( {} ),
		],
	},
	mode: inProduction ? 'production' : 'development',
	externals: {
		// Use external version of React
		'react'     : 'React',
		'react-dom' : 'ReactDOM',
	},
}
