<?php

/**
 * Widget for Rotating Ads
 */
class Adsanity_RAW_Widget extends WP_Widget {

	/**
	 * Sets up the widgets name
	 */
	public function __construct() {

		$widget_ops = array(
			'classname'                   => 'adsanity-rotating-ad-widget',
			'description'                 => __( 'Display a Rotating Ad', 'adsanity-raw' ),
			'customize_selective_refresh' => true,
		);

		parent::__construct( 'adsanity-rotating-ads', __( 'Adsanity - Rotating Ads', 'adsanity-raw' ), $widget_ops );

		add_action( 'admin_enqueue_scripts', array( $this, 'scripts' ) );

	}

	/**
	 * Enqueue the scripts for this widget
	 */
	public function scripts() {

		wp_enqueue_script(
			'adsanity-raw-widget',
			plugin_dir_url( __FILE__ ) . 'dist/js/widget.js',
			array( 'jquery' ),
			ADSANITY_RAW_VERSION,
			true
		);

	}

	/**
	 * Outputs the markup for this widget
	 */
	public function widget( $args, $instance ) {

		extract( $args, EXTR_SKIP );

		$widget_args = array(
			'is_widget'   => 'true',
			'title'       => $instance['title'],
			'group_id'    => $instance['group_id'],
			'time'        => $instance['time'],
			'align'       => $instance['align'],
			'widget_args' => $args,
		);

		if ( isset( $instance['max_width_enabled'] ) ) {
			$widget_args['max_width'] = $instance['max_width'];
		}

		if ( ! isset( $instance['random'] ) || ( 1 !== $instance['random'] && '1' !== $instance['random'] && true !== $instance['random'] ) ) {
			$widget_args['random'] = 0;
		}

		adsanity_show_rotating_ads( $widget_args );

	}

	/**
	 * Outputs the options form on admin
	 */
	public function form( $instance ) {

		$defaults = array(
			'title'    => '',
			'group_id' => 1,
			'time'     => 30,
			'align'    => 'alignnone',
			'random'   => 1,
		);

		$instance = wp_parse_args( $instance, $defaults );

		printf( '<p><label for="%s">%s</label>',
			esc_attr( $this->get_field_id( 'title' ) ),
			esc_html__( 'Title:', 'adsanity-raw' )
		);
			printf( '<input class="widefat" id="%s" name="%s" type="text" value="%s" /></p>',
				esc_attr( $this->get_field_id( 'title' ) ),
				esc_attr( $this->get_field_name( 'title' ) ),
				esc_attr( $instance['title'] )
			);

		// Display all add groups
		$args = array(
			'orderby' => 'name',
			'order'   => 'ASC'
		);

		$groups = get_terms( 'ad-group', $args );
		$group_id = $instance['group_id'];

		if ( count( $groups ) > 0 ) {

			printf( '<p><label for="%s">%s</label>',
				esc_attr( $this->get_field_id( 'group_id' ) ),
				esc_html__( 'Group: ', 'adsanity-raw' )
			);

			printf( '<select class="widefat" id="%s" name="%s">',
				esc_attr( $this->get_field_id( 'group_id' ) ),
				esc_attr( $this->get_field_name( 'group_id' ) )
			);

			foreach ( $groups as $group ) {
				printf( '<option value="%s" %s>%s</option>',
					esc_attr( $group->term_id ),
					selected( $group_id, $group->term_id, false ),
					esc_html( $group->name )
				);
			}
			echo '</select></label></p>';
		} else {
			printf( '<p>%s. %s <a href="%s">%s</a></p>',
				esc_html__( 'No ad groups found', 'adsanity-raw' ),
				esc_html__( 'Go', 'adsanity-raw' ),
				esc_attr( admin_url( 'edit-tags.php?taxonomy=ad-group&post_type=ads' ) ),
				esc_html__( 'create one', 'adsanity-raw' )
			);
		}

		// Time input
		printf( '<p><label for="%s">%s (%s):</label>',
			esc_attr( $this->get_field_id( 'time' ) ),
			esc_html__( 'Time', 'adsanity-raw' ),
			esc_html__( 'in seconds', 'adsanity-raw' )
		);

		printf( '<input class="widefat" id="%s" name="%s" type="text" value="%s" /></p>',
			esc_attr( $this->get_field_id( 'time' ) ),
			esc_attr( $this->get_field_name( 'time' ) ),
			esc_attr( $instance['time'] )
		);

		// Alignment input
		$align = $instance['align'];

		printf( '<p><label for="%s">%s: </label>',
			esc_attr( $this->get_field_id( 'align' ) ),
			esc_html__( 'Align', 'adsanity-raw' )
		);

		printf( '<select class="widefat" id="%s" name="%s">',
			esc_attr( $this->get_field_id( 'align' ) ),
			esc_attr( $this->get_field_name( 'align' ) )
		);
			$option = '<option value="%s" %s>%s</option>';

			printf( $option,
				esc_attr( 'alignnone' ),
				selected( $align, 'alignnone', false ),
				esc_html__( 'None', 'adsanity-raw' )
			);

			printf( $option,
				esc_attr( 'alignleft' ),
				selected( $align, 'alignleft', false ),
				esc_html__( 'Left', 'adsanity-raw' )
			);

			printf( $option,
				esc_attr( 'aligncenter' ),
				selected( $align, 'aligncenter', false ),
				esc_html__( 'Center', 'adsanity-raw' )
			);

			printf( $option,
				esc_attr( 'alignright' ),
				selected( $align, 'alignright', false ),
				esc_html__( 'Right', 'adsanity-raw' )
			);

		echo '</select></p>';

		// Max Width
		printf(
			'<hr style="margin-top:20px;">
			<p><label>
				%s
				<input class="adsanity-raw-max-width-enabled" type="checkbox" name="%s" %s>
			</label></p>',
			esc_html__( 'Max Width Enabled?', 'adsanity-raw' ),
			$this->get_field_name( 'max_width_enabled' ),
			checked( isset( $instance['max_width_enabled'] ), true, false )
		);

		printf(
			'<p%5$s>
				<label for="%1$s">%2$s</label>
				<input class="adsanity-max-width" id="%1$s" name="%3$s" type="number" value="%4$s">
			</p>',
			$this->get_field_id( 'max_width' ),
			esc_html__( 'Max Width (px):', 'adsanity-raw' ),
			$this->get_field_name( 'max_width' ),
			isset( $instance['max_width'] ) && $instance['max_width'] ? $instance['max_width'] : 100,
			isset( $instance['max_width_enabled'] ) ? '' : ' style="display:none;"'
		);

		// Random order
		printf(
			'<hr style="margin-top:20px;">
			<p><label>
				%s
				<input class="adsanity-raw-random" type="checkbox" name="%s" %s>
			</label></p>',
			esc_html__( 'Order Randomly? (defaults to ordering by publish date)', 'adsanity-raw' ),
			$this->get_field_name( 'random' ),
			checked( isset( $instance['random'] ) && $instance['random'], true, false )
		);

	}

	/**
	 * Processing widget options on save
	 */
	function update( $new_instance, $old_instance ) {

		$updated_instance = $new_instance;

		// Check to see if time is numeric
		if ( ! is_numeric( $updated_instance['time'] ) ) {
			$updated_instance['time'] = 30;
		}

		$updated_instance['random'] = isset( $new_instance['random'] ) ? 1 : 0;

		return $updated_instance;
	}
}
