<?php

/**
 * The core plugin class
 */
class Adsanity_RAW {

	/**
	 * The loader responsible for maintaining and registering all hooks that power the plugin
	 */
	protected $loader;

	/**
	 * Unique identifier
	 */
	protected $plugin_name;

	/**
	 * The version for this plugin
	 */
	protected $version;

	/**
	 * The core functionality
	 */
	public function __construct() {

		$this->plugin_name = 'adsanity_raw';
		$this->version = ADSANITY_RAW_VERSION;

		$this->load_dependencies();
		$this->define_admin_hooks();
		$this->define_public_hooks();
		$this->define_bb_hooks();

	}

	/**
	 * Load the depencies for this plugin
	 */
	private function load_dependencies() {

		/**
		 * Class responsible for orchestrating the actions and filters of the core plugin
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-adsanity-raw-loader.php';

		/**
		 * Class responsible for defining internationalization functionality
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-adsanity-raw-i18n.php';

		/**
		 * Class responsible for defining all actions that occur in the public-facing side
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'public/class-adsanity-raw-public.php';

		/**
		 * Class responsible for defining actions for the admin area
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/class-adsanity-raw-admin.php';

		/**
		 * Class responsible for Beaver Builder module
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'page-builders/beaver-builder/class-adsanity-raw-bb.php';

		/**
		 * Class responsible for Divi module
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'page-builders/divi/divi.php';

		/**
		 * Update engine
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'update-engine/remote-api.php';

		$this->loader = new Adsanity_RAW_Loader();
	}

	/**
	 * Define the locale for this plugin for internationalization.
	 */
	private function set_locale() {

		$plugin_i18n = new Adsanity_RAW_i18n();
		$this->loader->add_action( 'plugins_loaded', $plugin_i18n, 'load_plugin_textdomain' );

	}

	/**
	 * Register hooks related to the admin-area
	 *
	 * Adsanity_Rotating_Ads_Loader - Orchestrates the hooks of the plugin
	 */
	private function define_admin_hooks() {

		$plugin_admin = new Adsanity_RAW_Admin( $this->get_plugin_name(), $this->get_version() );

		$this->loader->add_filter( 'mce_external_plugins', $plugin_admin, 'add_tinymce_plugin', 100 );
		$this->loader->add_filter( 'mce_buttons', $plugin_admin, 'register_tinymce_button', 100 );

		$this->loader->add_action( 'admin_head', $plugin_admin, 'tinymce_javascript_object' );
		$this->loader->add_action( 'widgets_init', $plugin_admin, 'add_widget' );

		$this->loader->add_action( 'adsanity-addons', $plugin_admin, 'add_settings_tab' );
		$this->loader->add_action( 'admin_init', $plugin_admin, 'register_settings' );
		$this->loader->add_action( 'admin_init', $plugin_admin, 'register_sections' );
		$this->loader->add_action( 'admin_init', $plugin_admin, 'register_fields' );

		$this->loader->add_action( 'enqueue_block_editor_assets', $plugin_admin, 'gutenberg_scripts' );
		$this->loader->add_action( 'init', $plugin_admin, 'register_block_type' );
		$this->loader->add_action( 'adsanity_changelog_screen', $plugin_admin, 'changelog' );

	}

	/**
	 * Register public-facing hooks
	 */
	private function define_public_hooks() {

		/**
		 * Create new instance of public class for the plugin
		 */
		$plugin_public = new Adsanity_RAW_Public( $this->get_plugin_name(), $this->get_version() );

		$this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_scripts' );
		$this->loader->add_action( 'ads_setup', $plugin_public, 'show_in_rest' );
		$this->loader->add_action( 'init', $plugin_public, 'register_shortcodes' );
		$this->loader->add_action( 'init', $plugin_public, 'endpoint' );
		$this->loader->add_action( 'template_redirect', $plugin_public, 'iframe' );

	}

	/**
	 * Register Beaver Builder hooks
	 */
	private function define_bb_hooks() {

		/**
		 * Create new instance of BB class for the plugin
		 */
		$plugin_bb = new AdSanity_RAW_BB();

		$this->loader->add_action( 'init', $plugin_bb, 'load_module' );

	}

	/**
	 * Run the loader to execute all hooks
	 */
	public function run() {

		return $this->loader->run();

	}

	/**
	 * Retrieve the plugin name
	 */
	public function get_plugin_name() {

		return $this->plugin_name;

	}

	/**
	 * Reference to the class that orchestrates the hooks
	 */
	public function get_loader() {

		return $this->loader;

	}

	/**
	 * Retrieve the version number
	 */
	public function get_version() {

		return $this->version;

	}
}
