<?php

/**
 * Public facing functionality
 */
class Adsanity_RAW_Public {

	/**
	 * Unique identifier
	 */
	private $plugin_name;

	/**
	 * The version for this plugin
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Enqueue the scripts for the plugin
	 */
	public function enqueue_scripts() {

		wp_enqueue_script(
			$this->plugin_name,
			plugin_dir_url( __FILE__ ) . 'dist/js/adsanity-raw-public.js',
			array(),
			$this->version,
			true
		);

		wp_localize_script(
			$this->plugin_name,
			'adsanity_raw',
			array(
				'rest_url' => rest_url( '/wp/v2/ads/' ),
				'home_url' => home_url( '/' ),
			)
		);

	}

	/**
	 * Allow ads to be shown in rest
	 */
	public function show_in_rest( $args = array() ) {

		// Expose ads in the REST API
		$args['show_in_rest'] = true;

		return $args;
	}

	/**
	 * The main shortcode for rotating adds
	 */
	public function adsanity_rotating( $atts = array() ) {

		$defaults = array(
			'group_id' => 1,
			'time'     => 30,
			'align'    => 'alignnone',
			'return'   => true,
		);

		$atts = wp_parse_args( $atts, $defaults );

		return adsanity_show_rotating_ads( $atts );

	}

	/**
	 * Register all of the shortcodes
	 */
	public function register_shortcodes() {

		add_shortcode( 'adsanity_rotating', array( $this, 'adsanity_rotating' ) );

	}

	/**
	 * Adds endpoint for displaying an ad to be used in an iframe
	 *
	 * Ex: http://sandbox.test/adsanity-ad/1648
	 */
	public function endpoint() {

		add_rewrite_endpoint( 'adsanity-ad', EP_ROOT );

	}

	public function iframe() {

		global $wp_query;

		if ( ! isset( $wp_query->query_vars['adsanity-ad'] ) ) {
			return;
		}

		require_once plugin_dir_path( __FILE__ ) . 'partials/single-ad.php';
		exit;

	}
}
