( function() {

// Play nice with MonsterInsights Google Analytics
if ( typeof __gaTracker != 'undefined' ) {
	window.ga = __gaTracker;
}

// Polyfill for NodeList forEach
( function () {
	if ( typeof NodeList.prototype.forEach === "function" ) {
		return false;
	}
	NodeList.prototype.forEach = Array.prototype.forEach;
} )();

// Select all rotating ads divs
var adsanityRotatingAds = document.querySelectorAll( '.adsanity-rotating-ads' );

adsanityRotatingAds.forEach( function( element ) {

	// Extract data from element
	var ads = element.getAttribute( 'data-ids' );
	var time = element.getAttribute( 'data-timer' );
	var align = element.getAttribute( 'data-align' );
	var maxWidth = element.getAttribute( 'data-max-width' );

	if ( ! ads || ! time ) {
		return;
	}

	// Ads array from string
	ads = ads.split( ',' );

	// Time in seconds to milliseconds
	time *= 1000;

	rotateAds( ads, time, element, align, maxWidth );

} );

/**
 * Function for rotating ads
 */
function rotateAds( ads, time, element, align, maxWidth ) {

	// Start ad Id at the second ad, unless there is only one ad
	if ( ads.length !== 1 ) {
		var index = 1;
	} else {
		var index = 0;
	}

	/**
	 * Array for storing existing ads
	 * This is so we don't make extra requests and track more than once
	 *
	 * First element is initial rendered ad
	 */
	var outer = element.querySelector( 'div' ).outerHTML;
	if ( outer == undefined ) {
		return;
	}

	const existingAds = [
		{
			id     : ads[0],
			markup : outer,
		},
	];

	adsanityGetAd( ads, time, element, index, existingAds, align, maxWidth );

}

/**
 * Recursive function for displaying next ad using setTimeout
 */
function adsanityGetAd( ads, time, element, index, existingAds, align, maxWidth ) {

	// Don't let index exceed ads array length
	if ( index === ads.length ) {
		index = 0;
	}

	// Set timeout based on time to get next ad
	window.setTimeout( function() {

		// Check to see if we already have the ads stored
		if ( arrayContainsObjectValue( existingAds, 'id', ads[ index ] ) ) {
			existingAds.forEach( function( ad ) {
				if ( ads[ index ] === ad.id ) {
					element.innerHTML = ad.markup;
				}
			} );
			index++;
			adsanityGetAd( ads, time, element, index, existingAds, align, maxWidth );
			return;

		}

		// set Url
		var url = `${ adsanity_raw.rest_url + ads[ index ] }?track_this=1`;

		// Open up request and send it
		var request = new XMLHttpRequest();
		request.open( 'GET', url );
		request.send( null );

		// When request is ready, do stuff
		request.onreadystatechange = function() {
			if ( request.readyState === 4 ) {
				if ( request.status === 200 ) {
					var json = JSON.parse( request.responseText );
					var ad = json.rendered_ad;

					if ( maxWidth != 0 ) {
						ad = ad.replace( '>', ` style="max-width:${ maxWidth }px">` );
					}

					// Handle external ads and place them in an iframe
					ad = handleExternalAds( json, ad );

					element.innerHTML = ad;

					if ( align != '' ) {
						element.querySelector( 'div' ).classList.add( align );
						element.querySelector( 'div' ).classList.add( `adsanity-${ align }` );
					}
					existingAds.push( {
						id     : ads[ index ],
						markup : element.innerHTML,
					} );

					// Google Analytics logic
					var gati = element.querySelector( '.adsanity-gati' );
					if ( gati != null ) {
						var title = gati.getAttribute( 'data-title' );

						// Send a Google Analytics view event

						// Safety in case google analytics is not loaded yet
						if ( typeof ga != 'undefined' ) {

							ga( 'adsanity_gatracker.send', 'event', {
								eventCategory : 'AdSanity',
								eventAction   : 'view',
								eventLabel    : title,
							} );

						}

						// Add a click handler that sends a GA event
						element.addEventListener( 'click', function() {
							ga( 'adsanity_gatracker.send', 'event', {
								eventCategory : 'AdSanity',
								eventAction   : 'click',
								eventLabel    : title,
							} );
						} );
					}

					// increment index
					index++;

					// Call this function
					adsanityGetAd( ads, time, element, index, existingAds, align, maxWidth );
				} else {
					// Simple Error message
					console.log( "Error", request.statusText );

					index++;

					// Continue on
					adsanityGetAd( ads, time, element, index, existingAds, align, maxWidth );
				}
			}
		}

	}, time );
}

//
// Handle external ads and place them in an iframe
//
function handleExternalAds( json, ad ) {

	if ( 'external' !== json.ad_type ) {
		return ad;
	}

	const id = json.id;

	// The opening div tag for the ad, so we can maintain classes and styles
	const openingDiv = ad.match( /\<div(.*?)\>/ )[0];
	const src = `${ adsanity_raw.home_url }adsanity-ad/${ id }`;

	ad = `${ openingDiv }<div class="adsanity-inner"><iframe style="border:none;" src="${ src }"></iframe></div></div>`;

	return ad;

}

//
// Search array for a matching object value
//
function arrayContainsObjectValue( array, objectKey, search ) {

	for ( let index = 0; index < array.length; index++ ) {
		if ( array[ index ][ objectKey ] === search ) {
			return true;
		}
	}

	return false;

}

} )();
