<?php

/**
 * The template tag that is reference
 */
function adsanity_show_rotating_ads( $args = array() ) {

	$defaults = array(
		'is_widget'   => false,
		'widget_args' => array(),
		'title'       => false,
		'group_id'    => 0,
		'align'       => false,
		'return'      => false,
		'time'        => 30,
		'max_width'   => 0,
		'random'      => true,
	);

	// Parse arguments and extract variables
	$values = wp_parse_args( $args, $defaults );
	extract( $values, EXTR_SKIP );

	// Store this variable here, so that we can use it for our
	// markup and not pass it into the AdSanity Core template tag
	$is_rotating_widget = $is_widget;

	if ( ! is_array( $group_id ) ) {
		$group_id = array( $group_id );
	}

	$group_id = apply_filters( 'adsanity_hide_ad_group', $group_id );

	if ( empty( $group_id ) ) {
		return;
	}

	// Turn on output buffering if returning
	if( $return ) {
		ob_start();
	}

	$now = time();

	$args = array(
		'post_type' => 'ads',
		'tax_query' => array(
			array(
				'taxonomy' => 'ad-group',
				'terms'    => $group_id[0],
			),
		),
		'meta_query' => array(
			array(
				'key'     => '_start_date',
				'value'   => $now,
				'type'    => 'numeric',
				'compare' => '<='
			),
			array(
				'key'     => '_end_date',
				'value'   => $now,
				'type'    => 'numeric',
				'compare' => '>='
			)
		),
		'nopaging'      => true,
		'no_found_rows' => true,
	);

	// By default, ads are ordered randomly
	if ( $random ) {
		$args['orderby'] = 'rand';
	}

	$options = wp_parse_args(
		get_option( 'adsanity-rotating-ad-widget-options', array() ),
		array( 'allow-network-ads' => false )
	);

	if ( true != (bool) $options['allow-network-ads'] ) {
		$args['meta_query'][] = array(
			'key' 		=> '_code',
			'compare'	=> 'NOT EXISTS',
		);
	}

	$query = new WP_Query( $args );

	$ids_in_group = wp_list_pluck( $query->posts, 'ID' );

	foreach ( $ids_in_group as $id_in_group ) {
		if ( apply_filters( 'adsanity_hide_ad', false, $id_in_group ) ) {
			$index = array_search( $id_in_group, $ids_in_group );
			array_splice( $ids_in_group, $index, 1 );
		}
	}

	/**
	 * Allow the ids to be modified
	 */
	$ids_in_group = apply_filters( 'adsanity_raw_ids_in_group', $ids_in_group, $query );

	// It is possible that this is empty, if all ads in group are external
	if ( empty( $ids_in_group ) ) {
		return;
	}

	// Id to pass to show initial ad
	$id = $ids_in_group[0];

	// Create a string of ids for HTML markup
	$ids_in_group_string = implode( ',', $ids_in_group );

	$args = array(
		'is_widget' => false, // We do not want the template tag to act like a widget
		'post_id'   => $id,
		'align'     => $align,
		'return'    => true,
		'max_width' => $max_width,
	);

	if ( $is_rotating_widget ) {
		echo $widget_args['before_widget'];

		if ( $title && ! empty( $title ) ) {
			echo $widget_args['before_title'];
			echo $title;
			echo $widget_args['after_title'];
		}
	}

	$data_div = '<div class="adsanity-rotating-ads" data-ids="%1$s" data-timer="%2$s" data-align="%4$s" data-max-width="%5$s">%3$s</div>';

	$inner_ad = adsanity_show_ad( $args );

	// If this is a network ad, replace inner ad with iframe
	if ( get_post_meta( $id, '_code', true ) ) {
		$iframe = sprintf(
			'<div class="adsanity-inner"><iframe style="border:none;" src="%s"></iframe></div></div>',
			esc_url( sprintf( home_url( 'adsanity-ad/%d' ), intval( $id ) ) )
		);
		$inner_ad = preg_replace(
			'/\<div\sclass\=\"adsanity\-inner\"(.|\s)*/',
			$iframe,
			$inner_ad
		);
	}

	printf( $data_div,
		$ids_in_group_string,
		$time,
		$inner_ad,
		$align,
		$max_width
	);

	if ( $is_rotating_widget ) {
		echo $widget_args['after_widget'];
	}

	if ( $return ) {
		$output = ob_get_contents();
		ob_end_clean();
		return $output;
	}
}
