const webpack = require( 'webpack' );
const inProduction = process.env.NODE_ENV === 'production';
const UglifyJsPlugin = require( 'uglifyjs-webpack-plugin' );
const WebpackCleanPlugin = require( 'webpack-clean' );
const MiniCssExtractPlugin = require( 'mini-css-extract-plugin' );
const OptimizeCSSAssetsPlugin = require( 'optimize-css-assets-webpack-plugin' );
const path = require( 'path' );

const entry = {
	'admin/dist/js/blocks'               : './admin/src/js/blocks',
	'admin/dist/css/blocks'              : './admin/src/sass/blocks.scss',
	'admin/dist/js/tinymce'              : './admin/src/js/tinymce',
	'admin/dist/js/widget'               : './admin/src/js/widget',
	'public/dist/js/adsanity-raw-public' : './public/src/js/adsanity-raw-public',

	// Divi scripts live in their specific folder
	'page-builders/divi/scripts/builder-bundle.min' : './page-builders/divi/includes/loader.js',
}

module.exports = {
	entry,
	output: {
		path: path.resolve( __dirname, './' ),
		filename: '[name].js',
	},
	module: {
		rules: [
			{
				test: /\.js$/,
				use: 'babel-loader',
			},
			{
				test: /\.(png|jpg|svg|eot|ttf|woff)$/,
				use: [
					{
						loader: 'url-loader', options: {
							limit: 10000
						},
					},
				],
			},
			{
				test: /\.(css|scss)$/,
				use: [
					MiniCssExtractPlugin.loader,
					{
						loader: 'css-loader',
					},
					'sass-loader',
				],
			},
		],
		
	},
	plugins: [
		new MiniCssExtractPlugin({
			filename: "[name].css",
		}),
		new WebpackCleanPlugin(
			Object.keys( entry )
				.filter( ( key ) => key.includes( '/css/' ) )
				.map( ( key ) => key + '.js' )
		),
	],
	optimization: {
		minimizer: [
			new UglifyJsPlugin( {} ),
			new OptimizeCSSAssetsPlugin( {} ),
		],
	},
	mode: inProduction ? 'production' : 'development',
}
