<?php

/**
 * Handles ads.txt insertion/deletion
 */

class AdSanity_VII_Ads_Txt {

	function __construct( $ads_text = null ) {

		$this->ads_text = $ads_text;
		$this->format_ads_text();
		$this->insert_lines();

	}

	/**
	 * vi gives us new lines as \r\n
	 */
	private function format_ads_text() {

		$this->ads_text = str_replace( array( '\r\n', '\n', '\r' ), '
		', $this->ads_text );

	}

	/**
	 * Remove any current lines of vi from ads.txt
	 * (ends with comment: "# 41b5eef6")
	 */
	private function remove_vi_lines( $ads_txt_current_content ) {

		return preg_replace( '/(\n?).*\#\s41b5eef6(\n?)/', '', $ads_txt_current_content );

	}

	/**
	 * Insert new lines into ads.txt AdSanity setting
	 */
	private function insert_lines() {

		if ( null === $this->ads_text ) {
			// Set error transient
			set_transient( 'adsanity-vii-ads-txt-error', 1, 30 );
			return false;
		}

		// Get the option for current ads.txt text
		$adsanity_core_options = get_option( 'adsanity-options', [] );

		if ( is_array( $adsanity_core_options ) &&
		     array_key_exists( 'adstxt', $adsanity_core_options ) ) {
			$ads_txt_current_content = $adsanity_core_options['adstxt'];
		} else {
			$ads_txt_current_content = '';
		}

		// Remove any current vi lines
		$ads_txt_new_content = $this->remove_vi_lines( $ads_txt_current_content ) . '
		' . $this->ads_text;

		// Update the option
		$adsanity_options['adstxt'] = $ads_txt_new_content;
		update_option( 'adsanity-options', $adsanity_options );

		// Set success transient
		set_transient( 'adsanity-vii-ads-txt-success', 1, 30 );

	}

}
