<?php

/**
 * The settings-specific functionality of the plugin.
 *
 * @link       https://pixeljar.com
 * @since      1.0.0
 *
 * @package    AdSanity_VII
 * @subpackage AdSanity_VII/settings
 */

/**
 * Require the authentication class
 */
require_once plugin_dir_path( __FILE__ ) . 'class-adsanity-vii-auth.php';

/**
 * The settings-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the settings-specific stylesheet and JavaScript.
 *
 * @package    AdSanity_VII
 * @subpackage AdSanity_VII/settings
 * @author     Pixel Jar <info@pixeljar.com>
 */
class AdSanity_VII_Settings {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * The instance of the authentication class
	 */
	private $authentication;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;
		$this->get_authentication_instance();

	}

	/**
	 * Create a new instance of the authentication class
	 */
	public function get_authentication_instance() {

		$this->authentication = new AdSanity_VII_Auth( $this->plugin_name, $this->version );

	}

	/**
	 * Add a submenu page for video intelligence
	 */
	public function submenu_page() {

		add_submenu_page(
			'edit.php?post_type=ads',
			'video intelligence',
			'video intelligence',
			'manage_options',
			'adsanity-vii',
			array( $this, 'submenu_page_view' )
		);

	}

	/**
	 * The view for the submenu page
	 */
	public function submenu_page_view() {

		// VI Settings (API endpoints) and revenue data to pass into our view
		$vi_settings = $this->authentication->vi_settings;
		$revenue_data = $this->authentication->get_revenue_data();

		require_once plugin_dir_path( __FILE__ ) . 'partials/submenu-page.php';

	}

	/**
	 * Enqueue scripts and styles for the submenu page
	 */
	public function scripts( $hook_suffix ) {

		if ( 'ads_page_adsanity-vii' !== $hook_suffix ) {
			return;
		}

		wp_enqueue_script(
			$this->plugin_name . '-settings',
			plugin_dir_url( __FILE__ ) . 'dist/bundle.js',
			array(),
			$this->version,
			true
		);

		wp_enqueue_style(
			$this->plugin_name . '-settings',
			plugin_dir_url( __FILE__ ) . 'dist/bundle.css',
			array(),
			$this->version,
			'all'
		);

		// ADSANITY_VII_AUTH
		wp_localize_script(
			$this->plugin_name . '-settings',
			'ADSANITY_VII_AUTH',
			array(
				'isLoggedIn' => $this->authentication->is_authenticated(),
			)
		);

	}

}
