import Chart from 'chart.js';
import moment from 'moment';
import { formatCurrency, transformDate } from './helpers';

export default function() {

	const chart = document.getElementById( 'revenue-chart' )

	let revenue = JSON.parse( chart.getAttribute( 'data-revenue' ) );
	let dates = [];
	let money = [];

	if ( revenue.length ) {

		revenue.map( data => {
			dates.push( transformDate( data.date ) );
			money.push( data.revenue );
		} );

	}

	new Chart( chart, {
		type: 'line',
		
		data: {
			labels: dates,
			datasets: [ {
				label: "Revenue",
				data: money,
				backgroundColor: 'rgba(0, 142, 194, 0.1)',
				borderColor: 'rgb(0, 142, 194)',
			} ]
		},
		options: {
			legend: {
				display: false,
			},
			scales: {
				xAxes: [ {
					type: 'time',
					time: {
						tooltipFormat: 'MMM D',
						unit: 'day',
						unitStepSize: 1,
						displayFormats: {
							day: 'MMM D',
						},
					},
				} ],
				yAxes: [ {
					ticks: {
						callback: function( value, index, values ) {
							return formatCurrency( value );
						},
						beginAtZero: true,
					},
				} ],
			},
			tooltips: {
				callbacks: {
					label: function( tooltipItem, values ) {
						tooltipItem.yLabel = formatCurrency( tooltipItem.yLabel )
						return tooltipItem.yLabel;
					},
				},
			},
		},
	} );

}
