const path = require( 'path' );
const ExtractTextPlugin = require( 'extract-text-webpack-plugin' );
const inProduction = process.env.NODE_ENV === 'production';
const webpack = require( 'webpack' );
const wpPot = require('wp-pot');

module.exports = {
	entry: {
		'admin/dist/bundle'  : './admin/js/index.js',
		'public/dist/bundle' : './public/js/index.js',
		'settings/dist/bundle'  : './settings/js/index.js',
	},
	output: {
		path: path.resolve(__dirname, './'),
		filename: '[name].js',
	},
	resolve: {
		alias: {
			'vue$': 'vue/dist/vue.esm.js',
			'settings': './settings',
		},
	},
	mode: inProduction ? 'production' : 'development',
	module: {
		rules: [
			{
				test: /\.js$/,
				use: 'babel-loader',
			},
			{
				test: /\.s?(c|a)ss$/,
				use: ExtractTextPlugin.extract( {
					use: [
						{
							loader: 'css-loader',
							options: {
								url: false,
								minimize: inProduction,
							},
						},
						{
							loader: 'sass-loader',
						},
					],
				} ),
			},
			{
				test: /\.php$/,
				use: wpPot({
					destFile: 'languages/adsanity-vii.pot',
					domain: 'adsanity-vii',
					package: 'AdSanity vi Video Ads',
				})
			},
		],
	},
	externals: [
		{
			jquery: 'window.jQuery',
		},
	],
	plugins: [
		new ExtractTextPlugin( '[name].css' ),
	],
}
