<?php

/**
 * Ad post type meta box
 */

class AdSanity_AW_Meta_Box {

	function __construct() {}

	/**
	 * The actions and filters for this class
	 */
	public static function hooks() {

		add_action( 'admin_enqueue_scripts', array( __CLASS__, 'scripts' ) );
		add_action( 'add_meta_boxes', array( __CLASS__, 'meta_box' ) );
		add_action( 'save_post', array( __CLASS__, 'save_post' ) );

	}

	/**
	 * The styles and scripts for this meta box
	 */
	public static function scripts() {

		if ( ! function_exists( 'get_current_screen' ) ) {
			return;
		}

		$screen = get_current_screen();

		if ( 'ads' !== $screen->post_type || 'post' !== $screen->base ) {
			return;
		}

		wp_enqueue_style(
			ADSANITY_WA_SLUG . '-meta-box',
			ADSANITY_WA_CSS . 'meta-box.css',
			array(),
			ADSANITY_WA_VERSION,
			'all'
		);

	}

	/**
	 * Adds the meta box
	 */
	public static function meta_box() {

		add_meta_box(
			'adsanity-wa',
			esc_html__( 'Weight', 'adsanity' ),
			array( __CLASS__, 'meta_box_view' ),
			'ads',
			'side',
			'low'
		);

	}

	/**
	 * The view for the meta box
	 */
	public static function meta_box_view() {

		require_once( ADSANITY_WA_VIEWS . 'meta-box.php' );

	}

	/**
	 * Save post meta
	 */
	public static function save_post( $ad_id ) {

		if ( ! is_admin() ) {
			return;
		}

		if ( ! isset( $_POST['adsanity_wa_nonce'] ) ||
		     ! wp_verify_nonce( $_POST['adsanity_wa_nonce'], 'adsanity_wa' ) ) {
			return;
		}

		if ( ! isset( $_POST['adsanity_wa_weight'] ) ) {
			return;
		}

		$weight = intval( $_POST['adsanity_wa_weight'] );

		if ( $weight < 1 || $weight > 100 ) {
			return;
		}

		update_post_meta( $ad_id, 'adsanity_wa_weight', $weight );

	}

}

AdSanity_AW_Meta_Box::hooks();
