const webpack = require( 'webpack' );
const inProduction = process.env.NODE_ENV === 'production';
const WebpackCleanPlugin = require( 'webpack-clean' );
const wpPot = require( 'wp-pot' );
const MiniCssExtractPlugin = require( 'mini-css-extract-plugin' );
const OptimizeCssAssetsPlugin = require( 'optimize-css-assets-webpack-plugin' );

const entry = {
	'css/meta-box': './src/css/meta-box.scss',
}

module.exports = {
	entry,
	module: {
		rules: [
			{
				test: /\.js$/,
				use: 'babel-loader',
			},
			{
				test: /\.(png|jpg|svg|eot|ttf|woff)$/,
				use: [
					{
						loader: 'url-loader', options: {
							limit: 10000
						},
					},
				],
			},
			{
				test: /\.(css|scss)$/,
				use: [
					MiniCssExtractPlugin.loader,
					{
						loader: 'css-loader',
					},
					'sass-loader',
				],
			},
			{
				test: /\.php$/,
				use: wpPot({
					destFile: 'lang/adsanity.pot',
					domain: 'adsanity',
					package: 'AdSanity - Ad Impressions',
				}),
			},
		],
		
	},
	plugins: [
		new MiniCssExtractPlugin({
			filename: "[name].css",
		}),
		new WebpackCleanPlugin(
			// Array of JS files in the CSS folder
			Object.keys( entry )
				.filter( ( key ) => key.startsWith( 'css' ) )
				.map( ( key ) => `dist/${key}.js` )
		),
		new OptimizeCssAssetsPlugin(),
	],
	mode: inProduction ? 'production' : 'development',
}
