<?php
if ( ! defined( 'ABSPATH' ) ) { die( 'You are not allowed to call this file directly.' ); }

global $post;

$ad_id = get_the_ID();
$ad_target = get_post_meta( $ad_id, '_target', true );
$ad_permalink = get_permalink( $ad_id );

$ad_size = get_post_meta( $ad_id, '_size', true );
$classes = array(
	sprintf( 'ad-%s', $ad_size ),
	sprintf( 'adsanity-%s', $ad_size )
);

// Set by the wrapper function that includes this file
// Do not include it if this is an ad group with columns
if ( isset( $align ) && ! isset( $num_columns ) ) {

	$classes[] = esc_attr( $align );
	$classes[] = esc_attr( sprintf( 'adsanity-%s', $align ) );

}

$adsanity_post_class = apply_filters( 'adsanity_post_class', $classes, $post );
$adsanity_post_id = apply_filters( 'adsanity_post_id', sprintf( 'ad-%s', $ad_id ) );

// Trigger custom code before the ad wrapper
do_action( 'adsanity_before_ad_wrapper', $post );
?>

<div id="<?php echo esc_attr( $adsanity_post_id ); ?>" class="<?php echo esc_attr( implode( ' ', $adsanity_post_class ) ); ?>"<?php
	if ( isset( $max_width ) && $max_width ) {
		printf( 'style="max-width:%dpx"', intval( $max_width ) );
	}
?>><div class="adsanity-inner">

	<?php
		// Trigger custom code inside the wrapper, before the ad
		do_action( 'adsanity_before_ad', $post );

		// Hosted Ad
		if ( has_post_thumbnail( $ad_id ) ) {

			echo sprintf(
				'<a rel="nofollow" href="%s" %s>%s</a>',
				esc_attr( esc_url( $ad_permalink ) ),
				(bool) $ad_target ? ' target="_blank"' : '',
				get_the_post_thumbnail( $ad_id, 'full', array( 'loading' => 'normal', 'class' => 'no-lazy-load' ) )
			);

		} elseif ( $code = get_post_meta( $ad_id, '_code', true ) ) {

			$code = str_replace(
				array(
					'%link%',
					'[link]',
					'[timestamp]',
				),
				array(
					esc_attr( esc_url( $ad_permalink ) ),
					esc_attr( esc_url( add_query_arg( 'r', '', $ad_permalink ) ) ),
					esc_attr( time() ),
				),
				$code
			);
			echo $code;

		} elseif ( $text = get_post_meta( $ad_id, '_text', true ) ) {

			$background_color = get_post_meta( $ad_id, '_text_bg', true );
			$border_color = get_post_meta( $ad_id, '_text_border', true );
			$border_width = get_post_meta( $ad_id, '_text_border_width', true );

			$style = '';

			if ( $background_color && '' !== $background_color ) {
				$style .= sprintf(
					'background-color:%s;',
					$background_color
				);
			}

			if ( $border_width && '' !== $border_width ) {
				$style .= sprintf(
					'border:1px solid %s;',
					$border_color
				);
			}

			if ( $border_color && '' !== $border_color ) {
				$style .= sprintf(
					'border-width:%spx;',
					$border_width
				);
			}

			printf(
				'<div class="adsanity-text%s" style="%s;"><div>%s</div></div>',
				get_post_meta( $ad_id, '_text_vertical', true ) ? ' adsanity-vertical-text' : '',
				esc_attr( $style ),
				do_shortcode( $text )
			);

		} else {

			$ad_src = get_post_meta( $ad_id, 'ad_src', true );
			printf(
				'<iframe src="%s" frameborder="0" scrolling="no"></iframe>',
				esc_attr( trailingslashit( $ad_src ) )
			);

		}

		// Trigger custom code inside the wrapper, after the ad
		do_action( 'adsanity_after_ad', $post );
	?>

</div></div>

<?php
// Trigger custom code after the ad wrapper
do_action( 'adsanity_after_ad_wrapper', $post );
?>
