<?php

/**
 * Adds additional information on expired ads on the ad list page
 *
 * /wp-admin/edit.php?post_type=ads
 */

require_once ADSANITY_IMPRESSIONS_UTILITIES;

class AdSanity_AI_Ad_List {

	function __construct() {}

	/**
	 * The actions and filters for this class
	 */
	public static function hooks() {

		add_action( 'admin_enqueue_scripts', array( __CLASS__, 'script' ) );
		add_filter( 'adsanity_ads_posts_columns_adsanity-expires_value', array( __CLASS__, 'add_data' ), 10, 3 );

	}

	/**
	 * Enqueue the JavaScript for ad list page
	 */
	public static function script() {

		if ( ! function_exists( 'get_current_screen' ) ) {
			return;
		}
	
		$screen = get_current_screen();
	
		if ( ! isset( $screen->post_type ) ||
			 'ads' !== $screen->post_type ||
			 ! isset( $screen->base ) ||
			 'edit' !== $screen->base ) {
			return;
		}
	
		wp_enqueue_script(
			ADSANITY_IMPRESSIONS_SLUG . '-ad-list',
			ADSANITY_IMPRESSIONS_JS . 'ad-list.js',
			array( 'jquery', ),
			ADSANITY_IMPRESSIONS_VERSION,
			true
		);

		wp_enqueue_style(
			ADSANITY_IMPRESSIONS_SLUG . '-ad-list',
			ADSANITY_IMPRESSIONS_CSS . 'ad-list.css',
			array(),
			ADSANITY_IMPRESSIONS_VERSION,
			'all'
		);

	}

	/**
	 * Add data about ads with impression limits
	 */
	public static function add_data( $value, $column, $ad_id ) {

		$impression_type = get_post_meta( $ad_id, 'adsanity_ai_type', true );

		if ( ! $impression_type ) {
			return $value;
		}

		$impressions = 0;

		if ( 'all-time' === $impression_type ) {
			$impressions = AdSanity_AI_Utilities::get_all_time_views( $ad_id );
		} else if ( 'daily' === $impression_type ) {
			$impressions = AdSanity_AI_Utilities::get_daily_views( $ad_id );
		}

		$impression_limit = get_post_meta( $ad_id, 'adsanity_ai_limit', true );

		$data = sprintf(
			'<div
				class="adsanity-impressions-data"
				data-impression-type="%s"
				data-impressions="%s"
				data-impression-limit="%s"
				data-impression-daily-label="%s"
				data-impression-all-time-label="%s"
			></div>',
			esc_attr( $impression_type ),
			intval( $impressions ),
			intval( $impression_limit ),
			esc_attr__( 'Daily Impression Limit', 'adsanity-impressions' ),
			esc_attr__( 'All-Time Impression Limit', 'adsanity-impressions' )
		);

		return $value . $data;

	}

}

AdSanity_AI_Ad_List::hooks();
