<?php

/**
 * Whether or not to hide an ad
 */

require_once ADSANITY_IMPRESSIONS_UTILITIES;

class AdSanity_Hide_Ad {

	function __construct() {}

	/**
	 * The actions and filters for this class
	 */
	public static function hooks() {

		add_filter( 'adsanity_hide_ad', array( __CLASS__, 'hide_ad' ), 10, 2 );
		add_filter( 'adsanity_hide_ad_in_group', array( __CLASS__, 'hide_ads_in_groups' ), 10, 2 );

	}

	/**
	 * Checks to see if an ad should be
	 * hidden according to impression limit
	 */
	public static function hide_ad( $hide, $ad_id ) {

		if ( $hide ) {
			return $hide;
		}

		// Check for impression limit
		$type = get_post_meta( $ad_id, 'adsanity_ai_type', true );

		if ( ! $type ) {
			return $hide;
		}

		// Retrieve daily views
		if ( 'daily' === $type ) {
			return self::ad_reached_daily_limit( $ad_id );
		}

		// Retrieve all-time views
		if ( 'all-time' === $type ) {
			$hide = self::ad_reached_all_time_limit( $ad_id );

			// Manually expire this ad
			if ( $hide ) {
				update_post_meta( $ad_id, '_expired', 1 );
			}

			return $hide;
		}

		return false;

	}

	/**
	 * Finds ads in the given groups that should
	 * be hidden according to impression limits
	 */
	public static function hide_ads_in_groups( $hidden, $group_ids ) {

		// Retrieve all ads in groups with impression limits
		$args = array(
			'posts_per_page' => 99999,
			'post_type'      => 'ads',
			'fields'         => 'ids',
			'meta_key'       => 'adsanity_ai_type',
		);

		$ad_ids = get_posts( $args );

		// Check for exceeded limits
		foreach ( $ad_ids as $ad_id ) {
			$type = get_post_meta( $ad_id, 'adsanity_ai_type', true );

			if ( ! $type ) {
				continue;
			}

			// Retrieve daily views
			if ( 'daily' === $type ) {
				$hide = self::ad_reached_daily_limit( $ad_id );

				if ( $hide ) {
					$hidden[] = $ad_id;
				}

				continue;
			}

			// Retrieve all-time views
			if ( 'all-time' === $type ) {
				$hide = self::ad_reached_all_time_limit( $ad_id );

				// Manually expire this ad
				if ( $hide ) {
					update_post_meta( $ad_id, '_expired', 1 );
					$hidden[] = $ad_id;
				}

				continue;
			}

		}

		return $hidden;

	}

	/**
	 * Whether or not an ad has reached its daily impression limit
	 */
	public static function ad_reached_daily_limit( $ad_id ) {

		$limit = get_post_meta( $ad_id, 'adsanity_ai_limit', true );
		$views = AdSanity_AI_Utilities::get_daily_views( $ad_id );

		if ( intval( $views ) - 1 > intval( $limit ) ) {
			return true;
		}

		return false;

	}

	/**
	 * Whether or not and ad has reached its all-time impression limit
	 */
	public static function ad_reached_all_time_limit( $ad_id ) {

		$limit = get_post_meta( $ad_id, 'adsanity_ai_limit', true );
		$views = AdSanity_AI_Utilities::get_all_time_views( $ad_id );

		if ( intval( $views ) - 1 > intval( $limit ) ) {
			return true;
		}

		return false;

	}

}

AdSanity_Hide_Ad::hooks();
