<?php

/**
 * Ad post type meta box
 */

require_once ADSANITY_IMPRESSIONS_UTILITIES;

class AdSanity_Ad_Impressions {

	function __construct() {}

	/**
	 * The hooks for this class
	 */
	public static function hooks() {

		add_action( 'admin_enqueue_scripts', array( __CLASS__, 'scripts' ) );
		add_action( 'add_meta_boxes', array( __CLASS__, 'meta_box' ) );
		add_action( 'save_post', array( __CLASS__, 'save_post' ) );

	}

	/**
	 * Enqueue scripts on the ad post type
	 */
	public static function scripts( $hook_suffix ) {

		if ( ! AdSanity_AI_Utilities::is_ad_edit_screen() ) {
			return;
		}

		wp_enqueue_script(
			ADSANITY_IMPRESSIONS_SLUG . '-meta-box',
			ADSANITY_IMPRESSIONS_JS . 'meta-box.js',
			array( 'jquery', 'underscore', ),
			ADSANITY_IMPRESSIONS_VERSION,
			true
		);

		wp_enqueue_style(
			ADSANITY_IMPRESSIONS_SLUG . '-meta-box',
			ADSANITY_IMPRESSIONS_CSS . 'meta-box.css',
			array(),
			ADSANITY_IMPRESSIONS_VERSION,
			'all'
		);

	}

	/**
	 * Adds the meta box
	 */
	public static function meta_box() {

		add_meta_box(
			'adsanity-impressions',
			esc_html__( 'Impressions', 'adsanity' ),
			array( __CLASS__, 'meta_box_view' ),
			'ads',
			'normal',
			'low'
		);

	}

	/**
	 * Requires the meta box view file
	 */
	public static function meta_box_view() {

		require_once( ADSANITY_IMPRESSIONS_VIEWS . 'meta-box.php' );

	}

	/**
	 * Save post meta
	 */
	public static function save_post( $ad_id ) {

		if ( ! is_admin() ) {
			return;
		}

		if ( ! isset( $_POST['adsanity_ai'] ) ||
		     ! wp_verify_nonce( $_POST['adsanity_ai'], 'adsanity_ai' ) ) {
			return;
		}

		if ( ! isset( $_POST['adsanity_ai_type'] ) ) {
			delete_post_meta( $ad_id, 'adsanity_ai_type' );
			return;
		}

		$type = sanitize_text_field( $_POST['adsanity_ai_type'] );
		update_post_meta( $ad_id, 'adsanity_ai_type', $type );

		$limit = false;

		if ( 'daily' === $type && isset( $_POST['adsanity_ai_limit_daily'] ) ) {
			$limit = $_POST['adsanity_ai_limit_daily'];
		} else if ( 'all-time' === $type && isset( $_POST['adsanity_ai_limit_all'] ) ) {
			$limit = $_POST['adsanity_ai_limit_all'];

			// Delete the _expired post meta if this
			// is all-time and no longer expired
			if ( get_post_meta( $ad_id, '_expired', true ) ) {

				$all_time_views = AdSanity_AI_Utilities::get_all_time_views( $ad_id );

				if ( intval( $all_time_views ) < intval( $limit ) ) {
					delete_post_meta( $ad_id, '_expired' );
				}

			}
		}

		if ( $limit ) {
			update_post_meta( $ad_id, 'adsanity_ai_limit', intval( $limit ) );
		}

	}

}

AdSanity_Ad_Impressions::hooks();
