<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://www.pixeljar.com
 * @since      1.0.0
 *
 * @package    Adsanity_Urav
 * @subpackage Adsanity_Urav/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Adsanity_Urav
 * @subpackage Adsanity_Urav/public
 * @author     Pixel Jar <info@pixeljar.com>
 */
class Adsanity_Urav_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * The roles option for this plugin
	 *
	 * @since    1.0.0
	 */
	private $options;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;
		$this->get_option();

	}

	/**
	 * Retrieve the plugin options
	 *
	 * @since    1.0.0
	 */
	private function get_option() {

		$this->options = get_option( 'adsanity-user-role-ad-visibility-options', array() );

	}

	/**
	 * Hide ads based on roles option
	 *
	 * @since    1.0.0
	 */
	public function hide_ads( $value, $ad_id ) {

		if ( empty( $this->options ) ) {
			return $value;
		}

		$users = wp_get_current_user();
		if ( ! empty( array_intersect( $this->options, $users->roles ) ) ) {
			return true;
		}
		return false;

	}

	/**
	 * Hide ad groups based on roles option
	 *
	 * @since    1.0.0
	 */
	public function hide_ad_groups( $group_ids ) {

		$users = wp_get_current_user();
		if ( ! empty( array_intersect( $this->options, $users->roles ) ) ) {
			return array();
		}
		return $group_ids;

	}

}
